@@ -1,70 +1,80 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
+<TS version="2.0" language="de">
 <context>
     <name>BuiltinCommandLineOption</name>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="71"/>
-        <source>Skip forward in playlist</source>
-        <translation>Nächsten Titel in Wiedergabeliste abspielen</translation>
+        <source>Don&apos;t clear the playlist</source>
+        <translation>Wiedergabeliste nicht löschen</translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="72"/>
-        <source>Skip backwards in playlist</source>
-        <translation>Vorherigen Titel in Wiedergabeliste abspielen</translation>
-    </message>
-    <message>
-        <location filename="../builtincommandlineoption.cpp" line="64"/>
         <source>Start playing current song</source>
-        <translation>Aktuellen Titel abspielen</translation>
+        <translation>Aktuelles Lied abspielen</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="63"/>
-        <source>Don&apos;t clear the playlist</source>
-        <translation>Titel an Wiedergabeliste anhängen</translation>
-    </message>
-    <message>
-        <location filename="../builtincommandlineoption.cpp" line="65"/>
+        <location filename="../builtincommandlineoption.cpp" line="73"/>
         <source>Pause current song</source>
-        <translation>Aktuellen Titel anhalten</translation>
+        <translation>Aktuelles Lied pausieren</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="66"/>
+        <location filename="../builtincommandlineoption.cpp" line="74"/>
         <source>Pause if playing, play otherwise</source>
-        <translation>Wiedergabe anhalten oder fortsetzen</translation>
+        <translation>Wiedergabe pausieren oder fortsetzen</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="67"/>
+        <location filename="../builtincommandlineoption.cpp" line="75"/>
         <source>Stop current song</source>
-        <translation>Aktuellen Titel stoppen</translation>
+        <translation>Aktuelles Lied stoppen</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="68"/>
+        <location filename="../builtincommandlineoption.cpp" line="76"/>
         <source>Display Jump to File dialog</source>
         <translation>„Springe zu Titel“-Dialog anzeigen</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="69"/>
+        <location filename="../builtincommandlineoption.cpp" line="77"/>
         <source>Quit application</source>
         <translation>Anwendung beenden</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="70"/>
+        <location filename="../builtincommandlineoption.cpp" line="78"/>
         <source>Set playback volume (example: qmmp --volume 20)</source>
         <translation>Lautstärke der Wiedergabe einstellen (Beispiel: qmmp --volume 20)</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="73"/>
+        <location filename="../builtincommandlineoption.cpp" line="79"/>
+        <source>Mute/Restore volume</source>
+        <translation>Lautstärke stumm schalten/zurückstellen</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="80"/>
+        <source>Skip forward in playlist</source>
+        <translation>Nächsten Titel in Wiedergabeliste abspielen</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="81"/>
+        <source>Skip backwards in playlist</source>
+        <translation>Vorherigen Titel in Wiedergabeliste abspielen</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="82"/>
         <source>Show/hide application</source>
         <translation>Anwendung ein-/ausblenden</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="74"/>
+        <location filename="../builtincommandlineoption.cpp" line="83"/>
+        <source>Show main window</source>
+        <translation>Hauptfenster anzeigen</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="84"/>
         <source>Display Add File dialog</source>
         <translation>„Datei hinzufügen“-Dialog anzeigen</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="75"/>
+        <location filename="../builtincommandlineoption.cpp" line="85"/>
         <source>Display Add Directory dialog</source>
         <translation>„Verzeichnis hinzufügen“-Dialog anzeigen</translation>
     </message>
@@ -72,54 +82,64 @@
 <context>
     <name>QMMPStarter</name>
     <message>
-        <location filename="../qmmpstarter.cpp" line="286"/>
+        <location filename="../qmmpstarter.cpp" line="88"/>
+        <source>Unknown command</source>
+        <translation>Unbekannter Befehl</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="315"/>
         <source>Usage: qmmp [options] [files]</source>
         <translation>Aufruf: qmmp [Optionen] [Dateien]</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="287"/>
+        <location filename="../qmmpstarter.cpp" line="316"/>
         <source>Options:</source>
         <translation>Optionen:</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="291"/>
+        <location filename="../qmmpstarter.cpp" line="320"/>
         <source>Don&apos;t start the application</source>
         <translation>Die Anwendung nicht starten</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="293"/>
-        <source>Print version number and exit</source>
-        <translation>Gibt die Versionsnummer aus</translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="294"/>
-        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
-        <translation>Ideen, Patches und Bugreports an &lt;forkotov02@hotmail.ru&gt; senden</translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="299"/>
-        <source>QMMP version: %1</source>
-        <translation>Qmmp-Version: %1</translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="300"/>
-        <source>Compiled with Qt version: %1</source>
-        <translation>Kompiliert mit der Qt-Version %1</translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="301"/>
-        <source>Using Qt version: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../qmmpstarter.cpp" line="292"/>
+        <location filename="../qmmpstarter.cpp" line="321"/>
         <source>Display this text and exit</source>
         <translation>Zeigt diesen Hilfetext an</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="83"/>
-        <source>Unknown command</source>
-        <translation>Unbekannter Befehl</translation>
+        <location filename="../qmmpstarter.cpp" line="322"/>
+        <source>Print version number and exit</source>
+        <translation>Gibt die Versionsnummer aus</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="323"/>
+        <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
+        <translation>Ideen, Patches und Fehlerberichte an &lt;forkotov02@hotmail.ru&gt; senden</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="326"/>
+        <source>Command Line Help</source>
+        <translation>Befehlszeilenhilfe</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="339"/>
+        <source>QMMP version: %1</source>
+        <translation>Qmmp-Version: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="340"/>
+        <source>Compiled with Qt version: %1</source>
+        <translation>Kompiliert mit der Qt-Version %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="341"/>
+        <source>Using Qt version: %1</source>
+        <translation>Verwendet Qt-Version: %1</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="344"/>
+        <source>Qmmp Version</source>
+        <translation>Qmmp-Version</translation>
     </message>
 </context>
 </TS>
