@@ -5,66 +5,76 @@
     <name>BuiltinCommandLineOption</name>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="71"/>
-        <source>Skip forward in playlist</source>
-        <translation>Avancer dans la liste de lecture</translation>
+        <source>Don&apos;t clear the playlist</source>
+        <translation>Ne pas effacer la liste de lecture</translation>
     </message>
     <message>
         <location filename="../builtincommandlineoption.cpp" line="72"/>
-        <source>Skip backwards in playlist</source>
-        <translation>Reculer dans la liste de lecture</translation>
-    </message>
-    <message>
-        <location filename="../builtincommandlineoption.cpp" line="64"/>
         <source>Start playing current song</source>
         <translation>Démarrer la lecture du morceau courant</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="63"/>
-        <source>Don&apos;t clear the playlist</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../builtincommandlineoption.cpp" line="65"/>
+        <location filename="../builtincommandlineoption.cpp" line="73"/>
         <source>Pause current song</source>
         <translation>Mettre en pause le morceau courant</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="66"/>
+        <location filename="../builtincommandlineoption.cpp" line="74"/>
         <source>Pause if playing, play otherwise</source>
-        <translation>Mettre en pause si le morceau est joué ; autrement, le jouer</translation>
+        <translation>Mettre en pause si le morceau est joué, autrement, le jouer</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="67"/>
+        <location filename="../builtincommandlineoption.cpp" line="75"/>
         <source>Stop current song</source>
         <translation>Arrêter le morceau courant</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="68"/>
+        <location filename="../builtincommandlineoption.cpp" line="76"/>
         <source>Display Jump to File dialog</source>
         <translation>Afficher la boîte de dialogue « Aller au fichier »</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="69"/>
+        <location filename="../builtincommandlineoption.cpp" line="77"/>
         <source>Quit application</source>
-        <translation type="unfinished"></translation>
+        <translation>Quitter l&apos;application</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="70"/>
+        <location filename="../builtincommandlineoption.cpp" line="78"/>
         <source>Set playback volume (example: qmmp --volume 20)</source>
-        <translation type="unfinished"></translation>
+        <translation>Positionner le volume (par exemple : qmmp --volume 20)</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="73"/>
+        <location filename="../builtincommandlineoption.cpp" line="79"/>
+        <source>Mute/Restore volume</source>
+        <translation>Couper/remettre le son</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="80"/>
+        <source>Skip forward in playlist</source>
+        <translation>Avancer dans la liste de lecture</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="81"/>
+        <source>Skip backwards in playlist</source>
+        <translation>Reculer dans la liste de lecture</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="82"/>
         <source>Show/hide application</source>
-        <translation>Afficher ou cacher Qmmp</translation>
+        <translation>Afficher ou cacher l&apos;application</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="74"/>
+        <location filename="../builtincommandlineoption.cpp" line="83"/>
+        <source>Show main window</source>
+        <translation>Montrer la fenêtre principale</translation>
+    </message>
+    <message>
+        <location filename="../builtincommandlineoption.cpp" line="84"/>
         <source>Display Add File dialog</source>
         <translation>Afficher la boîte de dialogue « Ajouter un fichier »</translation>
     </message>
     <message>
-        <location filename="../builtincommandlineoption.cpp" line="75"/>
+        <location filename="../builtincommandlineoption.cpp" line="85"/>
         <source>Display Add Directory dialog</source>
         <translation>Afficher la boîte de dialogue « Ajouter un dossier »</translation>
     </message>
@@ -72,54 +82,64 @@
 <context>
     <name>QMMPStarter</name>
     <message>
-        <location filename="../qmmpstarter.cpp" line="83"/>
+        <location filename="../qmmpstarter.cpp" line="88"/>
         <source>Unknown command</source>
-        <translation type="unfinished"></translation>
+        <translation>Commande inconnue</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="286"/>
+        <location filename="../qmmpstarter.cpp" line="315"/>
         <source>Usage: qmmp [options] [files]</source>
         <translation>Usage : qmmp [options] [fichiers]</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="287"/>
+        <location filename="../qmmpstarter.cpp" line="316"/>
         <source>Options:</source>
         <translation>Options : </translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="291"/>
+        <location filename="../qmmpstarter.cpp" line="320"/>
         <source>Don&apos;t start the application</source>
-        <translation type="unfinished"></translation>
+        <translation>Ne pas démarrer l&apos;application</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="293"/>
+        <location filename="../qmmpstarter.cpp" line="321"/>
+        <source>Display this text and exit</source>
+        <translation>Afficher ce texte et quitter</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="322"/>
         <source>Print version number and exit</source>
         <translation>Imprimer le numéro de version et quitter</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="294"/>
+        <location filename="../qmmpstarter.cpp" line="323"/>
         <source>Ideas, patches, bugreports send to forkotov02@hotmail.ru</source>
         <translation>Idées, patches, rapports de bogues à envoyer à : forkotov02@hotmail.ru</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="299"/>
+        <location filename="../qmmpstarter.cpp" line="326"/>
+        <source>Command Line Help</source>
+        <translation>Aide de la ligne de commande</translation>
+    </message>
+    <message>
+        <location filename="../qmmpstarter.cpp" line="339"/>
         <source>QMMP version: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>QMMP version: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="300"/>
+        <location filename="../qmmpstarter.cpp" line="340"/>
         <source>Compiled with Qt version: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Compilé avec Qt version: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="301"/>
+        <location filename="../qmmpstarter.cpp" line="341"/>
         <source>Using Qt version: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Utilisation de Qt version: %1</translation>
     </message>
     <message>
-        <location filename="../qmmpstarter.cpp" line="292"/>
-        <source>Display this text and exit</source>
-        <translation>Afficher ce texte et quitter</translation>
+        <location filename="../qmmpstarter.cpp" line="344"/>
+        <source>Qmmp Version</source>
+        <translation>Version de Qmmp</translation>
     </message>
 </context>
 </TS>
