@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2010 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,10 +15,12 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
-#include <QtGui>
 
+#include <QMessageBox>
+#include <QTranslator>
+#include <QtPlugin>
 #include "mplayermetadatamodel.h"
 #include "settingsdialog.h"
 #include "mplayerengine.h"
@@ -58,7 +60,7 @@ AbstractEngine *MplayerEngineFactory::create(QObject *parent)
     return new MplayerEngine(parent);
 }
 
-QList<FileInfo *> MplayerEngineFactory::createPlayList(const QString &fileName, bool useMetaData)
+QList<FileInfo *> MplayerEngineFactory::createPlayList(const QString &fileName, bool useMetaData, QStringList *)
 {
     Q_UNUSED(useMetaData);
     QList<FileInfo *> info;
