@@ -19,7 +19,7 @@
         <location filename="../qmmpfiledialog.ui" line="72"/>
         <location filename="../qmmpfiledialog.ui" line="97"/>
         <source>...</source>
-        <translation type="unfinished"></translation>
+        <translation>…</translation>
     </message>
     <message>
         <location filename="../qmmpfiledialog.ui" line="50"/>
@@ -60,18 +60,18 @@
 <context>
     <name>QmmpFileDialogFactory</name>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="114"/>
-        <location filename="../qmmpfiledialog.cpp" line="124"/>
+        <location filename="../qmmpfiledialog.cpp" line="69"/>
+        <location filename="../qmmpfiledialog.cpp" line="79"/>
         <source>Qmmp File Dialog</source>
         <translation>Qmmp 文件对话</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="123"/>
+        <location filename="../qmmpfiledialog.cpp" line="78"/>
         <source>About Qmmp File Dialog</source>
         <translation>关于 Qmmp 文件对话</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="125"/>
+        <location filename="../qmmpfiledialog.cpp" line="80"/>
         <source>Written by:
 Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
@@ -80,7 +80,7 @@ Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
 Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialog.cpp" line="128"/>
+        <location filename="../qmmpfiledialog.cpp" line="83"/>
         <source>Some code is copied from the Qt library</source>
         <translation>一些源码基于 Qt 库</translation>
     </message>
@@ -88,22 +88,22 @@ Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
 <context>
     <name>QmmpFileDialogImpl</name>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="254"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="250"/>
         <source>Add</source>
         <translation>添加</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="267"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="263"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="281"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="277"/>
         <source>Directories</source>
         <translation>目录</translation>
     </message>
     <message>
-        <location filename="../qmmpfiledialogimpl.cpp" line="450"/>
+        <location filename="../qmmpfiledialogimpl.cpp" line="446"/>
         <source>%1 already exists.
 Do you want to replace it?</source>
         <translation>%1 早已存在。
