@@ -4,169 +4,228 @@
 <context>
     <name>Converter</name>
     <message>
-        <location filename="../converter.cpp" line="169"/>
-        <source>Track: %1</source>
-        <translation>Stopa: %1</translation>
+        <location filename="../converter.cpp" line="130"/>
+        <location filename="../converter.cpp" line="230"/>
+        <source>Cancelled</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../converter.cpp" line="171"/>
-        <source>Preset: %1</source>
-        <translation>Předvolba: %1</translation>
+        <location filename="../converter.cpp" line="145"/>
+        <location filename="../converter.cpp" line="212"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../converter.cpp" line="266"/>
-        <source>Encoding...</source>
-        <translation>Kóduji...</translation>
+        <location filename="../converter.cpp" line="177"/>
+        <source>Converting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converter.cpp" line="241"/>
+        <source>Encoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converter.cpp" line="279"/>
+        <source>Finished</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>ConverterDialog</name>
     <message>
         <location filename="../converterdialog.ui" line="14"/>
-        <source>Converter Settings</source>
-        <translation>Nastavení konvertoru</translation>
+        <source>Audio Converter</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../converterdialog.ui" line="29"/>
-        <source>Select tracks to convert:</source>
-        <translation>Vyberte stopy ke konverzi:</translation>
+        <location filename="../converterdialog.ui" line="44"/>
+        <source>Progress</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../converterdialog.ui" line="43"/>
+        <location filename="../converterdialog.ui" line="49"/>
+        <source>State</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.ui" line="63"/>
         <source>Output directory:</source>
         <translation>Výstupní adresář:</translation>
     </message>
     <message>
-        <location filename="../converterdialog.ui" line="53"/>
+        <location filename="../converterdialog.ui" line="80"/>
         <source>Output file name:</source>
         <translation>Výstupní soubor:</translation>
     </message>
     <message>
-        <location filename="../converterdialog.ui" line="63"/>
+        <location filename="../converterdialog.ui" line="97"/>
         <source>Preset:</source>
         <translation>Předvolba:</translation>
     </message>
     <message>
-        <location filename="../converterdialog.ui" line="73"/>
+        <location filename="../converterdialog.ui" line="114"/>
         <source>Overwrite existing files</source>
         <translation>Přepsat stávající soubory</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="90"/>
+        <location filename="../converterdialog.ui" line="124"/>
+        <source>Convert</source>
+        <translation type="unfinished">Konvertovat</translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.ui" line="131"/>
+        <source>Stop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="107"/>
         <source>Choose a directory</source>
         <translation>Vyberte adresář</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="110"/>
+        <location filename="../converterdialog.cpp" line="190"/>
         <source>Artist</source>
         <translation>Umělec</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="111"/>
+        <location filename="../converterdialog.cpp" line="191"/>
         <source>Album</source>
         <translation>Album</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="112"/>
+        <location filename="../converterdialog.cpp" line="192"/>
+        <source>Album Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.ui" line="39"/>
+        <location filename="../converterdialog.cpp" line="193"/>
         <source>Title</source>
         <translation>Název</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="113"/>
-        <source>Track number</source>
-        <translation>Číslo stopy</translation>
+        <location filename="../converterdialog.cpp" line="194"/>
+        <source>Track Number</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="114"/>
-        <source>Two-digit track number</source>
-        <translation>Dvoumístné číslo stopy</translation>
+        <location filename="../converterdialog.cpp" line="195"/>
+        <source>Two-digit Track Number</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="115"/>
+        <location filename="../converterdialog.cpp" line="200"/>
+        <source>Disc Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="201"/>
+        <source>File Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="202"/>
+        <source>File Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="212"/>
+        <source>Create a Copy</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="196"/>
         <source>Genre</source>
         <translation>Žánr</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="116"/>
+        <location filename="../converterdialog.cpp" line="128"/>
+        <location filename="../converterdialog.cpp" line="367"/>
+        <location filename="../converterdialog.cpp" line="373"/>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="133"/>
+        <source>Waiting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="197"/>
         <source>Comment</source>
         <translation>Poznámka</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="117"/>
+        <location filename="../converterdialog.cpp" line="198"/>
         <source>Composer</source>
         <translation>Skladatel</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="118"/>
+        <location filename="../converterdialog.cpp" line="199"/>
         <source>Duration</source>
         <translation>Délka</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="119"/>
-        <source>Disc number</source>
-        <translation>Číslo disku</translation>
-    </message>
-    <message>
-        <location filename="../converterdialog.cpp" line="120"/>
-        <source>File name</source>
-        <translation>Název souboru</translation>
-    </message>
-    <message>
-        <location filename="../converterdialog.cpp" line="130"/>
-        <source>Create a copy</source>
-        <translation>Vytvořit kopii</translation>
-    </message>
-    <message>
-        <location filename="../converterdialog.cpp" line="121"/>
+        <location filename="../converterdialog.cpp" line="203"/>
         <source>Year</source>
         <translation>Rok</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="122"/>
+        <location filename="../converterdialog.cpp" line="204"/>
         <source>Condition</source>
         <translation>Stav</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="128"/>
+        <location filename="../converterdialog.cpp" line="210"/>
         <source>Create</source>
         <translation>Vytvořit</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="129"/>
+        <location filename="../converterdialog.cpp" line="211"/>
         <source>Edit</source>
         <translation>Upravit</translation>
     </message>
     <message>
-        <location filename="../converterdialog.cpp" line="131"/>
+        <location filename="../converterdialog.cpp" line="213"/>
         <source>Delete</source>
         <translation>Odstranit</translation>
     </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="367"/>
+        <source>Unable to execute &quot;%1&quot;. Program not found.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../converterdialog.cpp" line="373"/>
+        <source>Process &quot;%1&quot; finished with error.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ConverterFactory</name>
     <message>
-        <location filename="../converterfactory.cpp" line="28"/>
+        <location filename="../converterfactory.cpp" line="30"/>
         <source>Converter Plugin</source>
         <translation>Modul konvertoru</translation>
     </message>
     <message>
-        <location filename="../converterfactory.cpp" line="49"/>
+        <location filename="../converterfactory.cpp" line="51"/>
         <source>About Converter Plugin</source>
         <translation>O modulu konvertoru</translation>
     </message>
     <message>
-        <location filename="../converterfactory.cpp" line="50"/>
+        <location filename="../converterfactory.cpp" line="52"/>
         <source>Qmmp Converter Plugin</source>
         <translation>Modul Qmmp pro konverzi</translation>
     </message>
     <message>
-        <location filename="../converterfactory.cpp" line="51"/>
+        <location filename="../converterfactory.cpp" line="53"/>
         <source>This plugin converts supported audio files to other file formats using external command-line encoders</source>
-        <translatorcomment>fakt je důležité, že jsou na příkazové řádce?</translatorcomment>
         <translation>Tento modul konvertuje podporované zvukové soubory do jiných formátů pomocí externích kodérů</translation>
     </message>
     <message>
-        <location filename="../converterfactory.cpp" line="53"/>
+        <location filename="../converterfactory.cpp" line="55"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -174,25 +233,15 @@
 <context>
     <name>ConverterHelper</name>
     <message>
-        <location filename="../converterhelper.cpp" line="35"/>
+        <location filename="../converterhelper.cpp" line="33"/>
         <source>Convert</source>
         <translation>Konvertovat</translation>
     </message>
     <message>
-        <location filename="../converterhelper.cpp" line="36"/>
+        <location filename="../converterhelper.cpp" line="34"/>
         <source>Meta+C</source>
         <translation>Meta+C</translation>
     </message>
-    <message>
-        <location filename="../converterhelper.cpp" line="42"/>
-        <source>Converting...</source>
-        <translation>Konvertuji...</translation>
-    </message>
-    <message>
-        <location filename="../converterhelper.cpp" line="43"/>
-        <source>Cancel</source>
-        <translation>Zrušit</translation>
-    </message>
 </context>
 <context>
     <name>PresetEditor</name>
