@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
+<TS version="2.0" language="de">
 <context>
     <name>CoverManager</name>
     <message>
@@ -17,24 +17,24 @@
 <context>
     <name>CoverManagerFactory</name>
     <message>
-        <location filename="../covermanagerfactory.cpp" line="29"/>
+        <location filename="../covermanagerfactory.cpp" line="31"/>
         <source>Cover Manager Plugin</source>
         <translation>Cover-Verwaltungsmodul</translation>
     </message>
     <message>
-        <location filename="../covermanagerfactory.cpp" line="49"/>
+        <location filename="../covermanagerfactory.cpp" line="51"/>
         <source>About Cover Manager Plugin</source>
         <translation>Über Cover-Verwaltungsmodul</translation>
     </message>
     <message>
-        <location filename="../covermanagerfactory.cpp" line="50"/>
+        <location filename="../covermanagerfactory.cpp" line="52"/>
         <source>Qmmp Cover Manager Plugin</source>
         <translation>Qmmp Cover-Verwaltungsmodul</translation>
     </message>
     <message>
-        <location filename="../covermanagerfactory.cpp" line="51"/>
+        <location filename="../covermanagerfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
