@@ -4,37 +4,64 @@
 <context>
     <name>FileOps</name>
     <message>
-        <location filename="../fileops.cpp" line="97"/>
+        <location filename="../fileops.cpp" line="98"/>
+        <location filename="../fileops.cpp" line="132"/>
         <source>Error</source>
         <translation>Chyba</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="98"/>
+        <location filename="../fileops.cpp" line="99"/>
+        <location filename="../fileops.cpp" line="133"/>
         <source>Destination directory doesn&apos;t exist</source>
         <translation>Cílový adresář neexistuje</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="103"/>
+        <location filename="../fileops.cpp" line="136"/>
+        <source>Move Files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../fileops.cpp" line="137"/>
+        <source>Are you sure you want to move %n file(s)?</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <location filename="../fileops.cpp" line="153"/>
         <source>Copying</source>
         <translation>Kopíruje se</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="104"/>
+        <location filename="../fileops.cpp" line="154"/>
+        <location filename="../fileops.cpp" line="244"/>
         <source>Stop</source>
         <translation>Přerušit</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="145"/>
+        <location filename="../fileops.cpp" line="199"/>
         <source>Copying file %1/%2</source>
         <translation>Kopíruje se soubor %1/%2</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="188"/>
-        <source>Remove files</source>
-        <translation>Odstranit soubory</translation>
+        <location filename="../fileops.cpp" line="243"/>
+        <source>Moving</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../fileops.cpp" line="276"/>
+        <source>Moving file %1/%2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../fileops.cpp" line="114"/>
+        <source>Remove Files</source>
+        <translation type="unfinished"></translation>
     </message>
     <message numerus="yes">
-        <location filename="../fileops.cpp" line="189"/>
+        <location filename="../fileops.cpp" line="115"/>
         <source>Are you sure you want to remove %n file(s) from disk?</source>
         <translation>
             <numerusform>Jste si jisti, že chcete z disku odstranit %n soubor?</numerusform>
@@ -46,22 +73,22 @@
 <context>
     <name>FileOpsFactory</name>
     <message>
-        <location filename="../fileopsfactory.cpp" line="30"/>
+        <location filename="../fileopsfactory.cpp" line="31"/>
         <source>File Operations Plugin</source>
         <translation>Modul pro operace se soubory</translation>
     </message>
     <message>
-        <location filename="../fileopsfactory.cpp" line="50"/>
+        <location filename="../fileopsfactory.cpp" line="51"/>
         <source>About File Operations Plugin</source>
         <translation>O modulu pro operace se soubory</translation>
     </message>
     <message>
-        <location filename="../fileopsfactory.cpp" line="51"/>
+        <location filename="../fileopsfactory.cpp" line="52"/>
         <source>Qmmp File Operations Plugin</source>
         <translation>Modul Qmmp pro operace se soubory</translation>
     </message>
     <message>
-        <location filename="../fileopsfactory.cpp" line="52"/>
+        <location filename="../fileopsfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
@@ -86,105 +113,6 @@
 </context>
 <context>
     <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.cpp" line="53"/>
-        <location filename="../settingsdialog.cpp" line="133"/>
-        <source>Copy</source>
-        <translation>Kopírovat</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="54"/>
-        <location filename="../settingsdialog.cpp" line="134"/>
-        <source>Rename</source>
-        <translation>Přejmenovat</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="92"/>
-        <location filename="../settingsdialog.cpp" line="56"/>
-        <location filename="../settingsdialog.cpp" line="136"/>
-        <source>Remove</source>
-        <translation>Odstranit</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="139"/>
-        <source>New action</source>
-        <translation>Nová akce</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="193"/>
-        <source>Artist</source>
-        <translation>Umělec</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="194"/>
-        <source>Album</source>
-        <translation>Album</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="195"/>
-        <source>Title</source>
-        <translation>Název</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="198"/>
-        <source>Genre</source>
-        <translation>Žánr</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="205"/>
-        <source>Year</source>
-        <translation>Rok</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="199"/>
-        <source>Comment</source>
-        <translation>Poznámka</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="196"/>
-        <source>Track number</source>
-        <translation>Číslo stopy</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="197"/>
-        <source>Two-digit track number</source>
-        <translation>Dvoumístné číslo stopy</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="200"/>
-        <source>Composer</source>
-        <translation>Skladatel</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="201"/>
-        <source>Duration</source>
-        <translation>Délka</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="202"/>
-        <source>Disc number</source>
-        <translation>Číslo disku</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="203"/>
-        <source>File name</source>
-        <translation>Název souboru</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="204"/>
-        <source>File path</source>
-        <translation>Cesta k souboru</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="206"/>
-        <source>Condition</source>
-        <translation>Stav</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="222"/>
-        <source>Choose a directory</source>
-        <translation>Vyberte adresář</translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>File Operations Settings</source>
@@ -211,10 +139,16 @@
         <translation>Zkratka</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="126"/>
-        <location filename="../settingsdialog.ui" line="143"/>
-        <source>...</source>
-        <translation>…</translation>
+        <location filename="../settingsdialog.ui" line="79"/>
+        <source>Add</source>
+        <translation>Přidat</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="92"/>
+        <location filename="../settingsdialog.cpp" line="54"/>
+        <location filename="../settingsdialog.cpp" line="134"/>
+        <source>Remove</source>
+        <translation>Odstranit</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="116"/>
@@ -222,14 +156,118 @@
         <translation>Cíl:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="79"/>
-        <source>Add</source>
-        <translation>Přidat</translation>
+        <location filename="../settingsdialog.ui" line="126"/>
+        <location filename="../settingsdialog.ui" line="143"/>
+        <source>...</source>
+        <translation>…</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="133"/>
         <source>File name pattern:</source>
         <translation>Vzor jména:</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="51"/>
+        <location filename="../settingsdialog.cpp" line="131"/>
+        <source>Copy</source>
+        <translation>Kopírovat</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="52"/>
+        <location filename="../settingsdialog.cpp" line="132"/>
+        <source>Rename</source>
+        <translation>Přejmenovat</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="53"/>
+        <location filename="../settingsdialog.cpp" line="133"/>
+        <source>Move</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="137"/>
+        <source>New action</source>
+        <translation>Nová akce</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="220"/>
+        <source>Artist</source>
+        <translation>Umělec</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="221"/>
+        <source>Album</source>
+        <translation>Album</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="222"/>
+        <source>Album Artist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="223"/>
+        <source>Title</source>
+        <translation>Název</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="224"/>
+        <source>Track Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="225"/>
+        <source>Two-digit Track Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="230"/>
+        <source>Disc Number</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="231"/>
+        <source>File Name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="232"/>
+        <source>File Path</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="226"/>
+        <source>Genre</source>
+        <translation>Žánr</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="227"/>
+        <source>Comment</source>
+        <translation>Poznámka</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="228"/>
+        <source>Composer</source>
+        <translation>Skladatel</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="229"/>
+        <source>Duration</source>
+        <translation>Délka</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="233"/>
+        <source>Year</source>
+        <translation>Rok</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="234"/>
+        <source>Condition</source>
+        <translation>Stav</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="247"/>
+        <source>Choose a directory</source>
+        <translation>Vyberte adresář</translation>
+    </message>
 </context>
 </TS>
