@@ -1,68 +1,94 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
+<TS version="2.0" language="de">
 <context>
     <name>FileOps</name>
     <message>
         <location filename="../fileops.cpp" line="98"/>
+        <location filename="../fileops.cpp" line="132"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
         <location filename="../fileops.cpp" line="99"/>
+        <location filename="../fileops.cpp" line="133"/>
         <source>Destination directory doesn&apos;t exist</source>
         <translation>Das Zielverzeichnis existiert nicht</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="104"/>
+        <location filename="../fileops.cpp" line="136"/>
+        <source>Move Files</source>
+        <translation>Dateien verschieben</translation>
+    </message>
+    <message numerus="yes">
+        <location filename="../fileops.cpp" line="137"/>
+        <source>Are you sure you want to move %n file(s)?</source>
+        <translation>
+            <numerusform>Sind Sie sicher, dass Sie %n Datei verschieben möchten?</numerusform>
+            <numerusform>Sind Sie sicher, dass Sie %n Dateien verschieben möchten?</numerusform>
+        </translation>
+    </message>
+    <message>
+        <location filename="../fileops.cpp" line="153"/>
         <source>Copying</source>
         <translation>Kopiere</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="105"/>
+        <location filename="../fileops.cpp" line="154"/>
+        <location filename="../fileops.cpp" line="244"/>
         <source>Stop</source>
         <translation>Stopp</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="146"/>
+        <location filename="../fileops.cpp" line="199"/>
         <source>Copying file %1/%2</source>
         <translation>Datei %1/%2 wird kopiert</translation>
     </message>
     <message>
-        <location filename="../fileops.cpp" line="189"/>
-        <source>Remove files</source>
+        <location filename="../fileops.cpp" line="243"/>
+        <source>Moving</source>
+        <translation>Verschiebevorgang</translation>
+    </message>
+    <message>
+        <location filename="../fileops.cpp" line="276"/>
+        <source>Moving file %1/%2</source>
+        <translation>Datei %1/%2 wird verschoben</translation>
+    </message>
+    <message>
+        <location filename="../fileops.cpp" line="114"/>
+        <source>Remove Files</source>
         <translation>Dateien entfernen</translation>
     </message>
     <message numerus="yes">
-        <location filename="../fileops.cpp" line="190"/>
+        <location filename="../fileops.cpp" line="115"/>
         <source>Are you sure you want to remove %n file(s) from disk?</source>
         <translation>
-            <numerusform>Möchten Sie wirklich %n Datei von der Festplatte entfernen?</numerusform>
-            <numerusform>Möchten Sie wirklich %n Dateien von der Festplatte entfernen?</numerusform>
+            <numerusform>Sind Sie sicher, dass Sie %n Datei von der Festplatte entfernen möchten?</numerusform>
+            <numerusform>Sind Sie sicher, dass Sie %n Dateien von der Festplatte entfernen möchten?</numerusform>
         </translation>
     </message>
 </context>
 <context>
     <name>FileOpsFactory</name>
     <message>
-        <location filename="../fileopsfactory.cpp" line="30"/>
+        <location filename="../fileopsfactory.cpp" line="31"/>
         <source>File Operations Plugin</source>
-        <translation>Datei-Aktionen-Modul</translation>
-    </message>
-    <message>
-        <location filename="../fileopsfactory.cpp" line="50"/>
-        <source>About File Operations Plugin</source>
-        <translation>Über Datei-Aktionen-Modul</translation>
+        <translation>Dateioperationsmodul</translation>
     </message>
     <message>
         <location filename="../fileopsfactory.cpp" line="51"/>
-        <source>Qmmp File Operations Plugin</source>
-        <translation>Qmmp Datei-Aktionen-Modul</translation>
+        <source>About File Operations Plugin</source>
+        <translation>Über Dateioperationsmodul</translation>
     </message>
     <message>
         <location filename="../fileopsfactory.cpp" line="52"/>
+        <source>Qmmp File Operations Plugin</source>
+        <translation>Qmmp Dateioperationsmodul</translation>
+    </message>
+    <message>
+        <location filename="../fileopsfactory.cpp" line="53"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
@@ -85,109 +111,10 @@
 </context>
 <context>
     <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.cpp" line="52"/>
-        <location filename="../settingsdialog.cpp" line="132"/>
-        <source>Copy</source>
-        <translation>Kopieren</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="53"/>
-        <location filename="../settingsdialog.cpp" line="133"/>
-        <source>Rename</source>
-        <translation>Umbenennen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="92"/>
-        <location filename="../settingsdialog.cpp" line="55"/>
-        <location filename="../settingsdialog.cpp" line="135"/>
-        <source>Remove</source>
-        <translation>Entfernen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="138"/>
-        <source>New action</source>
-        <translation>Neue Aktion</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="192"/>
-        <source>Artist</source>
-        <translation>Interpret</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="193"/>
-        <source>Album</source>
-        <translation>Album</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="194"/>
-        <source>Title</source>
-        <translation>Titel</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="197"/>
-        <source>Genre</source>
-        <translation>Genre</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="204"/>
-        <source>Year</source>
-        <translation>Jahr</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="198"/>
-        <source>Comment</source>
-        <translation>Kommentar</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="195"/>
-        <source>Track number</source>
-        <translation>Stücknummer</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="196"/>
-        <source>Two-digit track number</source>
-        <translation>Zweistellige Stücknummer</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="199"/>
-        <source>Composer</source>
-        <translation>Komponist</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="200"/>
-        <source>Duration</source>
-        <translation>Abspieldauer</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="201"/>
-        <source>Disc number</source>
-        <translation>CD-Nummer</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="202"/>
-        <source>File name</source>
-        <translation>Dateiname</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="203"/>
-        <source>File path</source>
-        <translation>Dateipfad</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="205"/>
-        <source>Condition</source>
-        <translation>Zustand</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="221"/>
-        <source>Choose a directory</source>
-        <translation>Ein Verzeichnis wählen</translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>File Operations Settings</source>
-        <translation>EInstellungen Datei-Aktionen-Modul</translation>
+        <translation>EInstellungen Dateioperationsmodul</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="48"/>
@@ -210,10 +137,16 @@
         <translation>Kurzbefehl</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="126"/>
-        <location filename="../settingsdialog.ui" line="143"/>
-        <source>...</source>
-        <translation>…</translation>
+        <location filename="../settingsdialog.ui" line="79"/>
+        <source>Add</source>
+        <translation>Hinzufügen</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="92"/>
+        <location filename="../settingsdialog.cpp" line="54"/>
+        <location filename="../settingsdialog.cpp" line="134"/>
+        <source>Remove</source>
+        <translation>Entfernen</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="116"/>
@@ -221,14 +154,118 @@
         <translation>Zielort:</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="79"/>
-        <source>Add</source>
-        <translation>Hinzufügen</translation>
+        <location filename="../settingsdialog.ui" line="126"/>
+        <location filename="../settingsdialog.ui" line="143"/>
+        <source>...</source>
+        <translation>…</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="133"/>
         <source>File name pattern:</source>
         <translation>Dateinamensmuster:</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="51"/>
+        <location filename="../settingsdialog.cpp" line="131"/>
+        <source>Copy</source>
+        <translation>Kopieren</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="52"/>
+        <location filename="../settingsdialog.cpp" line="132"/>
+        <source>Rename</source>
+        <translation>Umbenennen</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="53"/>
+        <location filename="../settingsdialog.cpp" line="133"/>
+        <source>Move</source>
+        <translation>Verschieben</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="137"/>
+        <source>New action</source>
+        <translation>Neue Aktion</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="220"/>
+        <source>Artist</source>
+        <translation>Interpret</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="221"/>
+        <source>Album</source>
+        <translation>Album</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="222"/>
+        <source>Album Artist</source>
+        <translation>Albuminterpret</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="223"/>
+        <source>Title</source>
+        <translation>Titel</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="224"/>
+        <source>Track Number</source>
+        <translation>Titelnummer</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="225"/>
+        <source>Two-digit Track Number</source>
+        <translation>Zweistellige Titelnummer</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="230"/>
+        <source>Disc Number</source>
+        <translation>Disc-Nummer</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="231"/>
+        <source>File Name</source>
+        <translation>Dateiname</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="232"/>
+        <source>File Path</source>
+        <translation>Dateipfad</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="226"/>
+        <source>Genre</source>
+        <translation>Genre</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="227"/>
+        <source>Comment</source>
+        <translation>Kommentar</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="228"/>
+        <source>Composer</source>
+        <translation>Komponist</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="229"/>
+        <source>Duration</source>
+        <translation>Abspieldauer</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="233"/>
+        <source>Year</source>
+        <translation>Jahr</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="234"/>
+        <source>Condition</source>
+        <translation>Zustand</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="247"/>
+        <source>Choose a directory</source>
+        <translation>Ein Verzeichnis wählen</translation>
+    </message>
 </context>
 </TS>
