@@ -4,32 +4,32 @@
 <context>
     <name>HalFactory</name>
     <message>
-        <location filename="../halfactory.cpp" line="30"/>
+        <location filename="../halfactory.cpp" line="32"/>
         <source>HAL Plugin</source>
-        <translation>HAL 插件</translation>
-    </message>
-    <message>
-        <location filename="../halfactory.cpp" line="50"/>
-        <source>About HAL Plugin</source>
-        <translation>關於 HAL 插件</translation>
-    </message>
-    <message>
-        <location filename="../halfactory.cpp" line="51"/>
-        <source>Qmmp HAL Plugin</source>
-        <translation>Qmmp HAL 插件</translation>
+        <translation>HAL 外掛</translation>
     </message>
     <message>
         <location filename="../halfactory.cpp" line="52"/>
+        <source>About HAL Plugin</source>
+        <translation>關於 HAL 外掛</translation>
+    </message>
+    <message>
+        <location filename="../halfactory.cpp" line="53"/>
+        <source>Qmmp HAL Plugin</source>
+        <translation>Qmmp HAL 外掛</translation>
+    </message>
+    <message>
+        <location filename="../halfactory.cpp" line="54"/>
         <source>This plugin provides removable devices detection using HAL</source>
         <translation>此插件利用 HAL 提供可移動設備的檢測</translation>
     </message>
     <message>
-        <location filename="../halfactory.cpp" line="53"/>
+        <location filename="../halfactory.cpp" line="55"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../halfactory.cpp" line="54"/>
+        <location filename="../halfactory.cpp" line="56"/>
         <source>Based on Solid (KDE hardware library)</source>
         <translation>基於 Solid (KDE 硬件程式庫)</translation>
     </message>
