@@ -22,93 +22,33 @@
 <context>
     <name>HotkeyFactory</name>
     <message>
-        <location filename="../hotkeyfactory.cpp" line="30"/>
+        <location filename="../hotkeyfactory.cpp" line="32"/>
         <source>Global Hotkey Plugin</source>
         <translation>全局熱鍵插件</translation>
     </message>
     <message>
-        <location filename="../hotkeyfactory.cpp" line="50"/>
+        <location filename="../hotkeyfactory.cpp" line="52"/>
         <source>About Global Hotkey Plugin</source>
         <translation>關於全局熱鍵插件</translation>
     </message>
     <message>
-        <location filename="../hotkeyfactory.cpp" line="51"/>
+        <location filename="../hotkeyfactory.cpp" line="53"/>
         <source>Qmmp Global Hotkey Plugin</source>
         <translation>Qmmp 全局熱鍵插件</translation>
     </message>
     <message>
-        <location filename="../hotkeyfactory.cpp" line="52"/>
+        <location filename="../hotkeyfactory.cpp" line="54"/>
         <source>This plugin adds support for multimedia keys or global key combinations</source>
         <translation>此插件支援添加多媒體熱鍵與全局熱鍵</translation>
     </message>
     <message>
-        <location filename="../hotkeyfactory.cpp" line="53"/>
+        <location filename="../hotkeyfactory.cpp" line="55"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
     <name>SettingsDialog</name>
-    <message>
-        <location filename="../settingsdialog.cpp" line="36"/>
-        <source>Play</source>
-        <translation>播放</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="37"/>
-        <source>Stop</source>
-        <translation>停止</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="38"/>
-        <source>Pause</source>
-        <translation>暫停</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="39"/>
-        <source>Play/Pause</source>
-        <translation>播放/暫停</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="40"/>
-        <source>Next</source>
-        <translation>下一曲</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="41"/>
-        <source>Previous</source>
-        <translation>上一曲</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="42"/>
-        <source>Show/Hide</source>
-        <translation>察看/隱藏</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="43"/>
-        <source>Volume +</source>
-        <translation>音量 +</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="44"/>
-        <source>Volume -</source>
-        <translation>音量 -</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="45"/>
-        <source>Forward 5 seconds</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="46"/>
-        <source>Rewind 5 seconds</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.cpp" line="47"/>
-        <source>Jump to track</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>Global Hotkey Plugin Settings</source>
@@ -129,5 +69,80 @@
         <source>Reset</source>
         <translation>重置</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="37"/>
+        <source>Play</source>
+        <translation>播放</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="38"/>
+        <source>Stop</source>
+        <translation>停止</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="39"/>
+        <source>Pause</source>
+        <translation>暫停</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="40"/>
+        <source>Play/Pause</source>
+        <translation>播放/暫停</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="41"/>
+        <source>Next</source>
+        <translation>下一曲</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="42"/>
+        <source>Previous</source>
+        <translation>上一曲</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="43"/>
+        <source>Show/Hide</source>
+        <translation>察看/隱藏</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="44"/>
+        <source>Volume +</source>
+        <translation>音量 +</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="45"/>
+        <source>Volume -</source>
+        <translation>音量 -</translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="46"/>
+        <source>Forward 5 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="47"/>
+        <source>Rewind 5 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="48"/>
+        <source>Jump to track</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="49"/>
+        <source>Mute</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="111"/>
+        <source>Warning</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.cpp" line="111"/>
+        <source>Key sequence &apos;%1&apos; is already used</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
