@@ -4,22 +4,22 @@
 <context>
     <name>MPRISFactory</name>
     <message>
-        <location filename="../mprisfactory.cpp" line="29"/>
+        <location filename="../mprisfactory.cpp" line="31"/>
         <source>MPRIS Plugin</source>
         <translation>MPRIS Module</translation>
     </message>
     <message>
-        <location filename="../mprisfactory.cpp" line="49"/>
+        <location filename="../mprisfactory.cpp" line="51"/>
         <source>About MPRIS Plugin</source>
         <translation>Over de MPRIS Module</translation>
     </message>
     <message>
-        <location filename="../mprisfactory.cpp" line="51"/>
-        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <location filename="../mprisfactory.cpp" line="53"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../mprisfactory.cpp" line="50"/>
+        <location filename="../mprisfactory.cpp" line="52"/>
         <source>Qmmp MPRIS Plugin</source>
         <translation>Qmmp MPRIS Module</translation>
     </message>
