@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2013 by Ilya Kotov                                 *
+ *   Copyright (C) 2008-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,6 +33,9 @@
 QmmpTrayIcon::QmmpTrayIcon(QObject *parent)
         : QSystemTrayIcon(parent)
 {
+#ifdef Q_WS_X11
+    m_showNiceToolTip = false;
+#endif
 }
 
 
@@ -64,15 +67,7 @@ bool QmmpTrayIcon::event(QEvent *e)
 
 void QmmpTrayIcon::wheelEvent(QWheelEvent *e)
 {
-    SoundCore *core = SoundCore::instance();
-    int volume = qMax(core->leftVolume(), core->rightVolume());
-    int balance = volume ? (core->rightVolume() - core->leftVolume()) * 100 / volume : volume;
-    volume += e->delta()/20;
-    volume = qMax(volume,0);
-    volume = qMin(volume,100);
-    core->setVolume(volume - qMax(balance,0)*volume/100,
-                    volume + qMin(balance,0)*volume/100);
-
+    SoundCore::instance()->changeVolume(e->delta()/20);
 }
 
 void QmmpTrayIcon::showToolTip()
