@@ -6,7 +6,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="14"/>
         <source>UDisks Plugin Settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Nastavení modulu UDisks</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="29"/>
@@ -42,29 +42,29 @@
 <context>
     <name>UDisksFactory</name>
     <message>
-        <location filename="../udisksfactory.cpp" line="30"/>
+        <location filename="../udisksfactory.cpp" line="32"/>
         <source>UDisks Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../udisksfactory.cpp" line="50"/>
-        <source>About UDisks Plugin</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../udisksfactory.cpp" line="51"/>
-        <source>Qmmp UDisks Plugin</source>
-        <translation type="unfinished"></translation>
+        <translation>Modul UDisks</translation>
     </message>
     <message>
         <location filename="../udisksfactory.cpp" line="52"/>
-        <source>This plugin provides removable devices detection using UDisks</source>
-        <translation type="unfinished"></translation>
+        <source>About UDisks Plugin</source>
+        <translation>O modulu UDisks</translation>
     </message>
     <message>
         <location filename="../udisksfactory.cpp" line="53"/>
+        <source>Qmmp UDisks Plugin</source>
+        <translation>Modul Qmmp UDisks</translation>
+    </message>
+    <message>
+        <location filename="../udisksfactory.cpp" line="54"/>
+        <source>This plugin provides removable devices detection using UDisks</source>
+        <translation>Tento modul poskytuje detekci výměnných médií pomocí UDisks</translation>
+    </message>
+    <message>
+        <location filename="../udisksfactory.cpp" line="55"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation type="unfinished">Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
@@ -72,12 +72,12 @@
     <message>
         <location filename="../udisksplugin.cpp" line="154"/>
         <source>Add CD &quot;%1&quot;</source>
-        <translation type="unfinished">Přidat CD „%1“</translation>
+        <translation>Přidat CD „%1“</translation>
     </message>
     <message>
         <location filename="../udisksplugin.cpp" line="160"/>
         <source>Add Volume &quot;%1&quot;</source>
-        <translation type="unfinished">Přidat svazek „%1“</translation>
+        <translation>Přidat svazek „%1“</translation>
     </message>
 </context>
 </TS>
