@@ -1,84 +1,89 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
+<TS version="2.0" language="de">
 <context>
     <name>DecoderFFmpegFactory</name>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="230"/>
-        <source>About FFmpeg Audio Plugin</source>
-        <translation>Über FFmpeg-Audio-Modul</translation>
-    </message>
-    <message>
-        <location filename="../decoderffmpegfactory.cpp" line="231"/>
-        <source>Qmmp FFmpeg Audio Plugin</source>
-        <translation>Qmmp FFmpeg-Audio-Modul</translation>
-    </message>
-    <message>
-        <location filename="../decoderffmpegfactory.cpp" line="232"/>
-        <source>Compiled against:</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../decoderffmpegfactory.cpp" line="245"/>
-        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
-        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
-    </message>
-    <message>
-        <location filename="../decoderffmpegfactory.cpp" line="125"/>
+        <location filename="../decoderffmpegfactory.cpp" line="158"/>
         <source>FFmpeg Plugin</source>
         <translation>FFmpeg-Modul</translation>
     </message>
     <message>
-        <location filename="../decoderffmpegfactory.cpp" line="127"/>
+        <location filename="../decoderffmpegfactory.cpp" line="160"/>
         <source>FFmpeg Formats</source>
         <translation>FFmpeg-Formate</translation>
     </message>
+    <message>
+        <location filename="../decoderffmpegfactory.cpp" line="267"/>
+        <source>About FFmpeg Audio Plugin</source>
+        <translation>Über FFmpeg-Audiomodul</translation>
+    </message>
+    <message>
+        <location filename="../decoderffmpegfactory.cpp" line="268"/>
+        <source>Qmmp FFmpeg Audio Plugin</source>
+        <translation>Qmmp FFmpeg-Audiomodul</translation>
+    </message>
+    <message>
+        <location filename="../decoderffmpegfactory.cpp" line="269"/>
+        <source>Compiled against:</source>
+        <translation>Kompiliert gegen:</translation>
+    </message>
+    <message>
+        <location filename="../decoderffmpegfactory.cpp" line="282"/>
+        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
+        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
+    </message>
 </context>
 <context>
     <name>FFmpegMetaDataModel</name>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="45"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
         <source>Length</source>
         <translation>Länge</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="46"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="51"/>
         <source>File size</source>
         <translation>Dateigröße</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="46"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="51"/>
         <source>KB</source>
         <translation>KB</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="47"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
         <source>Bitrate</source>
         <translation>Bitrate</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="47"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
         <source>kbps</source>
-        <translation>kbps</translation>
+        <translation>KBit/s</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
         <source>Sample rate</source>
         <translation>Abtastrate</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="59"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
         <source>Hz</source>
         <translation>Hz</translation>
     </message>
     <message>
-        <location filename="../ffmpegmetadatamodel.cpp" line="60"/>
+        <location filename="../ffmpegmetadatamodel.cpp" line="73"/>
         <source>Channels</source>
         <translation>Kanäle</translation>
     </message>
 </context>
 <context>
     <name>SettingsDialog</name>
+    <message>
+        <location filename="../settingsdialog.ui" line="14"/>
+        <source>FFmpeg Plugin Settings</source>
+        <translation>Einstellungen FFmpeg-Modul</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="55"/>
         <source>Formats</source>
@@ -89,6 +94,11 @@
         <source>Windows Media Audio</source>
         <translation>Windows Media Audio</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="68"/>
+        <source>Monkey&apos;s Audio (APE)</source>
+        <translation>Monkey’s Audio (APE)</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="75"/>
         <source>True Audio</source>
@@ -99,6 +109,11 @@
         <source>ADTS AAC</source>
         <translation>ADTS AAC</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="89"/>
+        <source>MP3 (MPEG audio layer 3)</source>
+        <translation>MP3 (MPEG Audio Layer 3)</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="96"/>
         <source>MPEG-4 AAC/ALAC</source>
@@ -112,7 +127,6 @@
     <message>
         <location filename="../settingsdialog.ui" line="110"/>
         <source>Shorten</source>
-        <translatorcomment>Name eines Dateiformats</translatorcomment>
         <translation>Shorten</translation>
     </message>
     <message>
@@ -123,7 +137,7 @@
     <message>
         <location filename="../settingsdialog.ui" line="124"/>
         <source>DTS/DTS-Core</source>
-        <translation>DTS/DTS-Core</translation>
+        <translation>DTS/DTS-Kern</translation>
     </message>
     <message>
         <location filename="../settingsdialog.ui" line="131"/>
@@ -135,20 +149,5 @@
         <source>VQF</source>
         <translation>VQF</translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>FFmpeg Plugin Settings</source>
-        <translation>Einstellungen FFmpeg-Modul</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="68"/>
-        <source>Monkey&apos;s Audio (APE)</source>
-        <translation>Monkey’s Audio (APE)</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="89"/>
-        <source>MP3 (MPEG audio layer 3)</source>
-        <translation>MP3 (MPEG Audio Layer 3)</translation>
-    </message>
 </context>
 </TS>
