@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2010-2013 by Ilya Kotov                                 *
+ *   Copyright (C) 2010-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -18,8 +18,11 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#include <QtGui>
 #include <QRegExp>
+#include <QMessageBox>
+#include <QTranslator>
+#include <QtPlugin>
+#include "settingsdialog.h"
 #include "gmehelper.h"
 #include "decoder_gme.h"
 #include "decodergmefactory.h"
@@ -52,7 +55,7 @@ const DecoderProperties DecoderGmeFactory::properties() const
     //properties.contentType = ;
     properties.shortName = "gme";
     properties.hasAbout = true;
-    properties.hasSettings = false;
+    properties.hasSettings = true;
     properties.noInput = true;
     properties.protocols << "gme";
     return properties;
@@ -64,7 +67,7 @@ Decoder *DecoderGmeFactory::create(const QString &path, QIODevice *input)
     return new DecoderGme(path);
 }
 
-QList<FileInfo *> DecoderGmeFactory::createPlayList(const QString &fileName, bool useMetaData)
+QList<FileInfo *> DecoderGmeFactory::createPlayList(const QString &fileName, bool useMetaData, QStringList *ignoredFiles)
 {
     QList <FileInfo*> list;
     GmeHelper helper;
@@ -75,7 +78,7 @@ QList<FileInfo *> DecoderGmeFactory::createPlayList(const QString &fileName, boo
         path.remove("gme://");
         path.remove(QRegExp("#\\d+$"));
         int track = fileName.section("#", -1).toInt();
-        list = createPlayList(path, true);
+        list = createPlayList(path, true, ignoredFiles);
         if (list.isEmpty() || track <= 0 || track > list.count())
         {
             qDeleteAll(list);
@@ -106,7 +109,8 @@ MetaDataModel* DecoderGmeFactory::createMetaDataModel(const QString &path, QObje
 
 void DecoderGmeFactory::showSettings(QWidget *parent)
 {
-    Q_UNUSED(parent);
+   SettingsDialog *d = new SettingsDialog(parent);
+   d->show();
 }
 
 void DecoderGmeFactory::showAbout(QWidget *parent)
