@@ -4,34 +4,57 @@
 <context>
     <name>DecoderGmeFactory</name>
     <message>
-        <location filename="../decodergmefactory.cpp" line="48"/>
+        <location filename="../decodergmefactory.cpp" line="51"/>
         <source>GME Plugin</source>
-        <translation>GME 插件</translation>
+        <translation>GME 外掛</translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="51"/>
+        <location filename="../decodergmefactory.cpp" line="54"/>
         <source>Game Music Files</source>
         <translation>Game 音頻文件</translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="114"/>
+        <location filename="../decodergmefactory.cpp" line="118"/>
         <source>About GME Audio Plugin</source>
         <translation>關於 Game 音頻文件</translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="115"/>
+        <location filename="../decodergmefactory.cpp" line="119"/>
         <source>Qmmp GME Audio Plugin</source>
         <translation>Qmmp Game 音頻文件</translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="116"/>
+        <location filename="../decodergmefactory.cpp" line="120"/>
         <source>This plugin uses Game_Music_Emu library to play game music files</source>
         <translation>此插件使用 Game_Music_Emu 庫播放 Game 音頻文件</translation>
     </message>
     <message>
-        <location filename="../decodergmefactory.cpp" line="117"/>
+        <location filename="../decodergmefactory.cpp" line="121"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
+<context>
+    <name>SettingsDialog</name>
+    <message>
+        <location filename="../settingsdialog.ui" line="14"/>
+        <source>GME Plugin Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="34"/>
+        <source>Fadeout length:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="44"/>
+        <source>ms</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="57"/>
+        <source>Enable fadeout</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
