@@ -4,32 +4,32 @@
 <context>
     <name>DecoderVorbisFactory</name>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="50"/>
+        <location filename="../decodervorbisfactory.cpp" line="55"/>
         <source>Ogg Vorbis Plugin</source>
         <translation>Ogg Vorbis 插件</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="53"/>
+        <location filename="../decodervorbisfactory.cpp" line="58"/>
         <source>Ogg Vorbis Files</source>
         <translation>Ogg Vorbis 文件</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="124"/>
+        <location filename="../decodervorbisfactory.cpp" line="137"/>
         <source>About Ogg Vorbis Audio Plugin</source>
         <translation>关于 Ogg Vorbis 音频插件</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="125"/>
+        <location filename="../decodervorbisfactory.cpp" line="138"/>
         <source>Qmmp Ogg Vorbis Audio Plugin</source>
         <translation>Qmmp Ogg Vorbis 音频插件</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="126"/>
+        <location filename="../decodervorbisfactory.cpp" line="139"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../decodervorbisfactory.cpp" line="127"/>
+        <location filename="../decodervorbisfactory.cpp" line="140"/>
         <source>Source code based on mq3 project</source>
         <translation>源代码基于 mq3 项目</translation>
     </message>
@@ -37,44 +37,44 @@
 <context>
     <name>VorbisMetaDataModel</name>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="51"/>
+        <location filename="../vorbismetadatamodel.cpp" line="58"/>
         <source>Length</source>
         <translation>长度</translation>
     </message>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="52"/>
+        <location filename="../vorbismetadatamodel.cpp" line="59"/>
         <source>Sample rate</source>
         <translation>取样率</translation>
     </message>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="52"/>
+        <location filename="../vorbismetadatamodel.cpp" line="59"/>
         <source>Hz</source>
-        <translation type="unfinished"></translation>
+        <translation>赫兹</translation>
     </message>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="53"/>
+        <location filename="../vorbismetadatamodel.cpp" line="60"/>
         <source>Channels</source>
         <translation>声音通道</translation>
     </message>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="54"/>
+        <location filename="../vorbismetadatamodel.cpp" line="61"/>
         <source>Bitrate</source>
         <translation>比特率</translation>
     </message>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="54"/>
+        <location filename="../vorbismetadatamodel.cpp" line="61"/>
         <source>kbps</source>
-        <translation type="unfinished"></translation>
+        <translation>千比特每秒</translation>
     </message>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="55"/>
+        <location filename="../vorbismetadatamodel.cpp" line="62"/>
         <source>File size</source>
         <translation>文件大小</translation>
     </message>
     <message>
-        <location filename="../vorbismetadatamodel.cpp" line="55"/>
+        <location filename="../vorbismetadatamodel.cpp" line="62"/>
         <source>KB</source>
-        <translation type="unfinished"></translation>
+        <translation>千字节</translation>
     </message>
 </context>
 </TS>
