@@ -4,28 +4,33 @@
 <context>
     <name>OutputALSAFactory</name>
     <message>
-        <location filename="../outputalsafactory.cpp" line="31"/>
+        <location filename="../outputalsafactory.cpp" line="33"/>
         <source>ALSA Plugin</source>
-        <translation>ALSA 插件</translation>
+        <translation>ALSA 外掛</translation>
     </message>
     <message>
-        <location filename="../outputalsafactory.cpp" line="56"/>
+        <location filename="../outputalsafactory.cpp" line="58"/>
         <source>About ALSA Output Plugin</source>
         <translation>關於 ALSA 匯出插件</translation>
     </message>
     <message>
-        <location filename="../outputalsafactory.cpp" line="57"/>
+        <location filename="../outputalsafactory.cpp" line="59"/>
         <source>Qmmp ALSA Output Plugin</source>
         <translation>Qmmp ALSA 匯出插件</translation>
     </message>
     <message>
-        <location filename="../outputalsafactory.cpp" line="58"/>
+        <location filename="../outputalsafactory.cpp" line="60"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
 </context>
 <context>
     <name>SettingsDialog</name>
+    <message>
+        <location filename="../settingsdialog.ui" line="14"/>
+        <source>ALSA Plugin Settings</source>
+        <translation>ALSA 插件設定</translation>
+    </message>
     <message>
         <location filename="../settingsdialog.ui" line="33"/>
         <source>Device Settings</source>
@@ -71,20 +76,15 @@
         <source>Period time (ms):</source>
         <translation>周期時間(ms)：</translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="213"/>
-        <source>Use snd_pcm_pause function</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="14"/>
-        <source>ALSA Plugin Settings</source>
-        <translation>ALSA 插件設定</translation>
-    </message>
     <message>
         <location filename="../settingsdialog.ui" line="193"/>
         <source>Use mmap access</source>
         <translation>使用內存對映</translation>
     </message>
+    <message>
+        <location filename="../settingsdialog.ui" line="213"/>
+        <source>Use snd_pcm_pause function</source>
+        <translation>使用 snd_pcm_pause 功能</translation>
+    </message>
 </context>
 </TS>
