@@ -4,22 +4,22 @@
 <context>
     <name>OutputJACKFactory</name>
     <message>
-        <location filename="../outputjackfactory.cpp" line="30"/>
+        <location filename="../outputjackfactory.cpp" line="33"/>
         <source>JACK Plugin</source>
-        <translation>JACK 插件</translation>
+        <translation>JACK 外掛</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="53"/>
+        <location filename="../outputjackfactory.cpp" line="56"/>
         <source>About Jack Output Plugin</source>
         <translation>關於 Jack 匯出插件</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="54"/>
+        <location filename="../outputjackfactory.cpp" line="57"/>
         <source>Qmmp Jack Output Plugin</source>
         <translation>Qmmp Jack 匯出插件</translation>
     </message>
     <message>
-        <location filename="../outputjackfactory.cpp" line="55"/>
+        <location filename="../outputjackfactory.cpp" line="58"/>
         <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
         <translation>作者：Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
     </message>
