@@ -1,32 +1,32 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="de_DE">
+<TS version="2.0" language="de">
 <context>
     <name>OutputOSSFactory</name>
     <message>
-        <location filename="../outputossfactory.cpp" line="36"/>
+        <location filename="../outputossfactory.cpp" line="38"/>
         <source>OSS Plugin</source>
         <translation>OSS-Modul</translation>
     </message>
-    <message>
-        <location filename="../outputossfactory.cpp" line="56"/>
-        <source>About OSS Output Plugin</source>
-        <translation>Über OSS-Ausgabe-Modul</translation>
-    </message>
-    <message>
-        <location filename="../outputossfactory.cpp" line="57"/>
-        <source>Qmmp OSS Output Plugin</source>
-        <translation>Qmmp OSS-Ausgabe-Modul</translation>
-    </message>
     <message>
         <location filename="../outputossfactory.cpp" line="58"/>
-        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
-        <translation>Autor: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
+        <source>About OSS Output Plugin</source>
+        <translation>Über OSS-Ausgabemodul</translation>
     </message>
     <message>
         <location filename="../outputossfactory.cpp" line="59"/>
+        <source>Qmmp OSS Output Plugin</source>
+        <translation>Qmmp OSS-Ausgabemodul</translation>
+    </message>
+    <message>
+        <location filename="../outputossfactory.cpp" line="60"/>
+        <source>Written by: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</source>
+        <translation>Geschrieben von: Yuriy Zhuravlev &lt;slalkerg@gmail.com&gt;</translation>
+    </message>
+    <message>
+        <location filename="../outputossfactory.cpp" line="61"/>
         <source>Based on code by: Brad Hughes &lt;bhughes@trolltech.com&gt;</source>
-        <translation>Basiert auf Quellcode von: Brad Hughes &lt;bhughes@trolltech.com&gt;</translation>
+        <translation>Basiert auf Code von: Brad Hughes &lt;bhughes@trolltech.com&gt;</translation>
     </message>
 </context>
 <context>
@@ -37,54 +37,44 @@
         <translation>Einstellungen OSS-Modul</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="30"/>
+        <location filename="../settingsdialog.ui" line="33"/>
         <source>Device Settings</source>
-        <translation>Geräte-Einstellungen</translation>
+        <translation>Geräteinstellungen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="42"/>
+        <location filename="../settingsdialog.ui" line="45"/>
         <source>Audio device</source>
         <translation>Audiogerät</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="58"/>
+        <location filename="../settingsdialog.ui" line="61"/>
         <source>Mixer device</source>
         <translation>Mixergerät</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="81"/>
+        <location filename="../settingsdialog.ui" line="84"/>
         <source>Advanced Settings</source>
         <translation>Erweiterte Einstellungen</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="93"/>
+        <location filename="../settingsdialog.ui" line="96"/>
         <source>Soundcard</source>
         <translation>Soundkarte</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="157"/>
+        <location filename="../settingsdialog.ui" line="160"/>
         <source>Buffer time (ms):</source>
         <translation>Pufferzeit (ms):</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="167"/>
+        <location filename="../settingsdialog.ui" line="170"/>
         <source>Period time (ms):</source>
         <translation>Zeitraster (ms):</translation>
     </message>
     <message>
-        <location filename="../settingsdialog.ui" line="197"/>
+        <location filename="../settingsdialog.ui" line="200"/>
         <source>PCM over Master</source>
         <translation>PCM over Master</translation>
     </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="224"/>
-        <source>Cancel</source>
-        <translation>Abbrechen</translation>
-    </message>
-    <message>
-        <location filename="../settingsdialog.ui" line="231"/>
-        <source>OK</source>
-        <translation>OK</translation>
-    </message>
 </context>
 </TS>
