@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2012 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,7 +17,6 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
-#include <QtGui>
 #include <QFileDialog>
 #include <QDir>
 #include <QAction>
@@ -36,6 +35,7 @@
 #include <qmmpui/playlistmanager.h>
 #include <qmmpui/mediaplayer.h>
 #include <qmmpui/configdialog.h>
+#include <qmmpui/qmmpuisettings.h>
 #include "hotkeyeditor.h"
 #include "skinnedsettings.h"
 #include "mainwindow.h"
@@ -59,19 +59,33 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     m_vis = 0;
     m_update = false;
     setWindowFlags(Qt::Window | Qt::FramelessWindowHint |
-                   Qt::WindowCloseButtonHint | Qt::WindowSystemMenuHint);
+                   Qt::WindowCloseButtonHint | Qt::WindowMinMaxButtonsHint | Qt::WindowSystemMenuHint);
+
     setWindowTitle("Qmmp");
 
+    m_titleFormatter.setPattern("%if(%p,%p - %t,%t)");
+
     new ActionManager(this);
 
     m_player = MediaPlayer::instance();
     m_core = SoundCore::instance();
     m_pl_manager = PlayListManager::instance();
     m_uiHelper = UiHelper::instance();
+    m_ui_settings = QmmpUiSettings::instance();
 
     //user interface
     m_skin = new Skin(this);
-    resize(275 * m_skin->ratio(),116 * m_skin->ratio());
+#ifdef Q_WS_X11
+    QString wm_name = WindowSystem::netWindowManagerName();
+    if(wm_name.contains("metacity", Qt::CaseInsensitive) ||
+            wm_name.contains("marko", Qt::CaseInsensitive) ||
+            wm_name.contains("mutter", Qt::CaseInsensitive) ||
+            wm_name.contains("gnome", Qt::CaseInsensitive))
+        resize(275 * m_skin->ratio(),116 * m_skin->ratio());
+    else
+#endif
+        setFixedSize(275 * m_skin->ratio(),116 * m_skin->ratio());
+
     Dock *dock = new Dock(this);
     dock->setMainWidget(this);
     m_display = new MainDisplay(this);
@@ -95,17 +109,18 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect (m_playlist,SIGNAL(play()),SLOT(play()));
     connect (m_playlist,SIGNAL(pause()), m_core ,SLOT(pause()));
     connect (m_playlist,SIGNAL(stop()),SLOT(stop()));
-    connect (m_playlist,SIGNAL(eject()),SLOT(addFile()));
+    connect (m_playlist,SIGNAL(eject()),SLOT(playFiles()));
     connect (m_playlist,SIGNAL(loadPlaylist()),SLOT(loadPlaylist()));
     connect (m_playlist,SIGNAL(savePlaylist()),SLOT(savePlaylist()));
 
-    connect(m_display,SIGNAL(shuffleToggled(bool)),m_pl_manager,SLOT(setShuffle(bool)));
-    connect(m_display,SIGNAL(repeatableToggled(bool)),m_pl_manager,SLOT(setRepeatableList(bool)));
+    connect(m_display,SIGNAL(shuffleToggled(bool)),m_ui_settings,SLOT(setShuffle(bool)));
+    connect(m_display,SIGNAL(repeatableToggled(bool)),m_ui_settings,SLOT(setRepeatableList(bool)));
 
     connect(m_core, SIGNAL(stateChanged(Qmmp::State)), SLOT(showState(Qmmp::State)));
     connect(m_core, SIGNAL(elapsedChanged(qint64)),m_playlist, SLOT(setTime(qint64)));
     connect(m_core, SIGNAL(metaDataChanged()),SLOT(showMetaData()));
     connect(m_uiHelper, SIGNAL(toggleVisibilityCalled()), SLOT(toggleVisibility()));
+    connect(m_uiHelper, SIGNAL(showMainWindowCalled()), SLOT(showAndRaise()));
 
     readSettings();
     m_display->setEQ(m_equalizer);
@@ -117,9 +132,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 }
 
 MainWindow::~MainWindow()
-{
-    qDebug("%s", Q_FUNC_INFO);
-}
+{}
 
 void MainWindow::play()
 {
@@ -143,12 +156,6 @@ void MainWindow::backward()
     m_core->seek(qMax(qint64(0), m_core->elapsed() - KEY_OFFSET));
 }
 
-void MainWindow::setVolume(int volume, int balance)
-{
-    m_core->setVolume(volume-qMax(balance,0)*volume/100,
-                      volume+qMin(balance,0)*volume/100);
-}
-
 void MainWindow::pause(void)
 {
     m_core->pause();
@@ -174,15 +181,15 @@ void MainWindow::showState(Qmmp::State state)
     switch ((int) state)
     {
     case Qmmp::Playing:
-        if (m_pl_manager->currentPlayList()->currentItem())
-            m_equalizer->loadPreset(m_pl_manager->currentPlayList()->currentItem()->url().section("/",-1));
+        if (m_pl_manager->currentPlayList()->currentTrack())
+            m_equalizer->loadPreset(m_pl_manager->currentPlayList()->currentTrack()->url().section("/",-1));
         break;
     case Qmmp::Paused:
         break;
     case Qmmp::Stopped:
         m_playlist->setTime(-1);
-        if (m_playlist->currentItem())
-            setWindowTitle(m_playlist->currentItem()->text());
+        if (m_pl_manager->currentPlayList()->currentTrack())
+            setWindowTitle(m_titleFormatter.format(m_pl_manager->currentPlayList()->currentTrack()));
         else
             setWindowTitle("Qmmp");
         break;
@@ -191,20 +198,29 @@ void MainWindow::showState(Qmmp::State state)
 
 void MainWindow::showMetaData()
 {
-    if (m_playlist->currentItem() &&
-        m_playlist->currentItem()->url() == m_core->metaData().value(Qmmp::URL))
+    PlayListTrack *track = m_pl_manager->currentPlayList()->currentTrack();
+    if (track && track->url() == m_core->metaData().value(Qmmp::URL))
     {
-        setWindowTitle(m_playlist->currentItem()->text());
+        setWindowTitle(m_titleFormatter.format(track));
     }
 }
 
 void MainWindow::closeEvent (QCloseEvent *)
 {
-    writeSettings();
-    m_playlist->close();
-    m_equalizer->close();
     if (!m_hideOnClose || !m_uiHelper->visibilityControl())
         m_uiHelper->exit();
+    else
+    {
+        m_playlist->close();
+        m_equalizer->close();
+    }
+}
+
+void MainWindow::hideEvent (QHideEvent *)
+{
+    writeSettings();
+    m_playlist->writeSettings();
+    m_equalizer->writeSettings();
 }
 
 void MainWindow::addDir()
@@ -214,7 +230,12 @@ void MainWindow::addDir()
 
 void MainWindow::addFile()
 {
-    m_uiHelper->addFile(this);
+    m_uiHelper->addFiles(this);
+}
+
+void MainWindow::playFiles()
+{
+    m_uiHelper->playFiles(this);
 }
 
 void MainWindow::changeEvent (QEvent * event)
@@ -229,33 +250,9 @@ void MainWindow::readSettings()
 {
     QSettings settings(Qmmp::configFile(), QSettings::IniFormat);
     settings.beginGroup("Skinned");
-    if (!m_update)
-    {
+    m_titleFormatter.setPattern(settings.value("window_title_format","%if(%p,%p - %t,%t)").toString());
 
-        move(settings.value("mw_pos", QPoint(100, 100)).toPoint()); //geometry
-        m_startHidden = settings.value("start_hidden", false).toBool();
-        if(settings.value("always_on_top", false).toBool())
-        {
-            ACTION(ActionManager::WM_ALLWAYS_ON_TOP)->setChecked(true);
-            setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
-        }
-        ACTION(ActionManager::WM_STICKY)->setChecked(settings.value("show_on_all_desktops",
-                                                                    false).toBool());
-        show();
-        qApp->processEvents();
-        //visibility
-        m_playlist->setVisible(settings.value("pl_visible",true).toBool());
-        qApp->processEvents();
-        m_equalizer->setVisible(settings.value("eq_visible",true).toBool());
-        qApp->processEvents();
-        // Repeat/Shuffle
-        m_display->setIsRepeatable(m_pl_manager->isRepeatableList());
-        m_display->setIsShuffle(m_pl_manager->isShuffle());
-        ACTION(ActionManager::REPEAT_ALL)->setChecked(m_pl_manager->isRepeatableList());
-        ACTION(ActionManager::SHUFFLE)->setChecked(m_pl_manager->isShuffle());
-        m_update = true;
-    }
-    else
+    if (m_update)
     {
         if(ACTION(ActionManager::WM_ALLWAYS_ON_TOP)->isChecked())
         {
@@ -273,6 +270,36 @@ void MainWindow::readSettings()
         qApp->processEvents();
         m_playlist->setVisible(m_display->isPlaylistVisible());
         m_equalizer->setVisible(m_display->isEqualizerVisible());
+
+        if (m_pl_manager->currentPlayList()->currentTrack())
+            setWindowTitle(m_titleFormatter.format(m_pl_manager->currentPlayList()->currentTrack()));
+    }
+    else
+    {
+        move(settings.value("mw_pos", QPoint(100, 100)).toPoint()); //geometry
+        m_startHidden = settings.value("start_hidden", false).toBool();
+        if(settings.value("always_on_top", false).toBool())
+        {
+            ACTION(ActionManager::WM_ALLWAYS_ON_TOP)->setChecked(true);
+            setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
+        }
+        ACTION(ActionManager::WM_STICKY)->setChecked(settings.value("show_on_all_desktops",
+                                                                    false).toBool());
+        show();
+        qApp->processEvents();
+        //visibility
+        m_playlist->setVisible(settings.value("pl_visible",true).toBool());
+        qApp->processEvents();
+        m_equalizer->setVisible(settings.value("eq_visible",true).toBool());
+        qApp->processEvents();
+        // Repeat/Shuffle
+        m_display->setIsRepeatable(m_ui_settings->isRepeatableList());
+        m_display->setIsShuffle(m_ui_settings->isShuffle());
+        ACTION(ActionManager::REPEAT_ALL)->setChecked(m_ui_settings->isRepeatableList());
+        ACTION(ActionManager::SHUFFLE)->setChecked(m_ui_settings->isShuffle());
+        ACTION(ActionManager::REPEAT_TRACK)->setChecked(m_ui_settings->isRepeatableTrack());
+        ACTION(ActionManager::NO_PL_ADVANCE)->setChecked(m_ui_settings->isNoPlayListAdvance());
+        m_update = true;
     }
 #ifdef Q_WS_X11
     WindowSystem::changeWinSticky(winId(), ACTION(ActionManager::WM_STICKY)->isChecked());
@@ -308,6 +335,7 @@ void MainWindow::writeSettings()
     settings.setValue("double_size", ACTION(ActionManager::WM_DOUBLE_SIZE)->isChecked());
     settings.setValue("always_on_top", ACTION(ActionManager::WM_ALLWAYS_ON_TOP)->isChecked());
     settings.setValue("show_on_all_desktops", ACTION(ActionManager::WM_STICKY)->isChecked());
+    settings.setValue("antialiasing", ACTION(ActionManager::WM_ANTIALIASING)->isChecked());
     settings.endGroup();
 }
 
@@ -326,7 +354,7 @@ void MainWindow::showSettings()
 
 void MainWindow::toggleVisibility()
 {
-    if (isHidden())
+    if (isHidden() || isMinimized())
     {
         show();
         raise();
@@ -344,10 +372,7 @@ void MainWindow::toggleVisibility()
         setFocus ();
         if (isMinimized())
         {
-            if (isMaximized())
-                showMaximized();
-            else
-                showNormal();
+            showNormal();
         }
 #ifdef Q_WS_X11
         WindowSystem::changeWinSticky(winId(), ACTION(ActionManager::WM_STICKY)->isChecked());
@@ -366,6 +391,17 @@ void MainWindow::toggleVisibility()
     qApp->processEvents();
 }
 
+void MainWindow::showAndRaise()
+{
+    if(isHidden() || isMinimized())
+        toggleVisibility();
+    else
+    {
+        activateWindow();
+        raise();
+    }
+}
+
 void MainWindow::createActions()
 {
     m_mainMenu = new QMenu(this);
@@ -385,35 +421,43 @@ void MainWindow::createActions()
     viewMenu->addAction(SET_ACTION(ActionManager::WM_ALLWAYS_ON_TOP, this, SLOT(updateSettings())));
     viewMenu->addAction(SET_ACTION(ActionManager::WM_STICKY, this, SLOT(updateSettings())));
     viewMenu->addAction(SET_ACTION(ActionManager::WM_DOUBLE_SIZE, this, SLOT(updateSettings())));
+    viewMenu->addAction(SET_ACTION(ActionManager::WM_ANTIALIASING, this, SLOT(updateSettings())));
 
     QMenu *plMenu = m_mainMenu->addMenu(tr("Playlist"));
-    plMenu->addAction(SET_ACTION(ActionManager::REPEAT_ALL, m_pl_manager, SLOT(setRepeatableList(bool))));
-    plMenu->addAction(SET_ACTION(ActionManager::REPEAT_TRACK, m_player, SLOT(setRepeatable(bool))));
-    plMenu->addAction(SET_ACTION(ActionManager::SHUFFLE, m_pl_manager, SLOT(setShuffle(bool))));
-    plMenu->addAction(SET_ACTION(ActionManager::NO_PL_ADVANCE, m_player,
-                                 SLOT(setNoPlaylistAdvance(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::REPEAT_ALL, m_ui_settings, SLOT(setRepeatableList(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::REPEAT_TRACK, m_ui_settings, SLOT(setRepeatableTrack(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::SHUFFLE, m_ui_settings, SLOT(setShuffle(bool))));
+    plMenu->addAction(SET_ACTION(ActionManager::NO_PL_ADVANCE, m_ui_settings,
+                                 SLOT(setNoPlayListAdvance(bool))));
     plMenu->addAction(SET_ACTION(ActionManager::STOP_AFTER_SELECTED, m_pl_manager,
                                  SLOT(stopAfterSelected())));
     plMenu->addAction(SET_ACTION(ActionManager::CLEAR_QUEUE, m_pl_manager, SLOT(clearQueue())));
-    connect(m_pl_manager, SIGNAL(repeatableListChanged(bool)),
+    connect(m_ui_settings, SIGNAL(repeatableListChanged(bool)),
             ACTION(ActionManager::REPEAT_ALL), SLOT(setChecked(bool)));
-    connect(m_player, SIGNAL (repeatableChanged(bool)),
+    connect(m_ui_settings, SIGNAL (repeatableTrackChanged(bool)),
             ACTION(ActionManager::REPEAT_TRACK), SLOT(setChecked(bool)));
-    connect(m_player, SIGNAL (noPlaylistAdvanceChanged(bool)),
+    connect(m_ui_settings, SIGNAL (noPlayListAdvanceChanged(bool)),
             ACTION(ActionManager::NO_PL_ADVANCE), SLOT(setChecked(bool)));
-    connect(m_pl_manager, SIGNAL(shuffleChanged(bool)),
+    connect(m_ui_settings, SIGNAL(shuffleChanged(bool)),
             ACTION(ActionManager::SHUFFLE), SLOT(setChecked(bool)));
 
+    QMenu *audioMenu = m_mainMenu->addMenu(tr("Audio"));
+    audioMenu->addAction(SET_ACTION(ActionManager::VOL_ENC, m_core, SLOT(volumeUp())));
+    audioMenu->addAction(SET_ACTION(ActionManager::VOL_DEC, m_core, SLOT(volumeDown())));
+    audioMenu->addAction(SET_ACTION(ActionManager::VOL_MUTE, m_core, SLOT(setMuted(bool))));
+    connect(m_core, SIGNAL(mutedChanged(bool)), ACTION(ActionManager::VOL_MUTE), SLOT(setChecked(bool)));
+
     m_visMenu = new VisualMenu(this);
     m_mainMenu->addMenu(m_visMenu);
     m_mainMenu->addMenu(m_uiHelper->createMenu(UiHelper::TOOLS_MENU, tr("Tools"), this));
+
     m_mainMenu->addSeparator();
     m_mainMenu->addAction(SET_ACTION(ActionManager::SETTINGS, this, SLOT(showSettings())));
     m_mainMenu->addSeparator();
     m_mainMenu->addAction(SET_ACTION(ActionManager::ABOUT, this, SLOT(about())));
     m_mainMenu->addAction(SET_ACTION(ActionManager::ABOUT_QT, qApp, SLOT(aboutQt())));
     m_mainMenu->addSeparator();
-    m_mainMenu->addAction(SET_ACTION(ActionManager::QUIT, this, SLOT(close())));
+    m_mainMenu->addAction(SET_ACTION(ActionManager::QUIT, m_uiHelper, SLOT(exit())));
 
     QAction* forward = new QAction(this);
     forward->setShortcut(QKeySequence(Qt::Key_Right));
