@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006-2013 by Ilya Kotov                                 *
+ *   Copyright (C) 2006-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -23,12 +23,13 @@
 #include <QMenu>
 #include <QAction>
 #include <QSignalMapper>
-#include <QHBoxLayout>
 #include <QCloseEvent>
+#include <QInputDialog>
 #include <qmmpui/playlistitem.h>
 #include <qmmpui/playlistmodel.h>
 #include <qmmpui/playlistmanager.h>
 #include <qmmpui/uihelper.h>
+#include <qmmpui/qmmpuisettings.h>
 #include <qmmp/soundcore.h>
 #include "dock.h"
 #include "skin.h"
@@ -44,6 +45,7 @@
 #include "playlistselector.h"
 #include "windowsystem.h"
 #include "actionmanager.h"
+#include "playlistheader.h"
 #include "playlist.h"
 
 PlayList::PlayList (PlayListManager *manager, QWidget *parent)
@@ -52,6 +54,7 @@ PlayList::PlayList (PlayListManager *manager, QWidget *parent)
     setAttribute(Qt::WA_AlwaysShowToolTips,true);
     setWindowTitle(tr("Playlist"));
     m_pl_manager = manager;
+    m_ui_settings = QmmpUiSettings::instance();
     m_update = false;
     m_resize = false;
     m_skin = Skin::instance();
@@ -60,9 +63,28 @@ PlayList::PlayList (PlayListManager *manager, QWidget *parent)
     m_pl_browser = 0;
     m_pl_selector = 0;
 
-    resize (275*m_ratio, 116*m_ratio);
-    setSizeIncrement (25*m_ratio, 29*m_ratio);
-    setMinimumSize(275*m_ratio, 116*m_ratio);
+#ifdef Q_WS_X11
+    QString wm_name = WindowSystem::netWindowManagerName();
+    m_compiz = wm_name.contains("compiz", Qt::CaseInsensitive);
+    if(wm_name.contains("metacity", Qt::CaseInsensitive) ||
+       wm_name.contains("openbox", Qt::CaseInsensitive))
+        setWindowFlags (Qt::Tool | Qt::FramelessWindowHint);
+    else
+#endif
+        setWindowFlags (Qt::Dialog | Qt::FramelessWindowHint);
+
+#ifdef Q_WS_X11
+    if(m_compiz)
+    {
+        setFixedSize(275*m_ratio, 116*m_ratio);
+    }
+    else
+#endif
+    {
+        resize (275*m_ratio, 116*m_ratio);
+        setSizeIncrement (25*m_ratio, 29*m_ratio);
+        setMinimumSize(275*m_ratio, 116*m_ratio);
+    }
 
     m_listWidget = new ListWidget (this);
     m_plslider = new PlayListSlider (this);
@@ -76,11 +98,11 @@ PlayList::PlayList (PlayListManager *manager, QWidget *parent)
     m_resizeWidget->setCursor(m_skin->getCursor (Skin::CUR_PSIZE));
     m_pl_control = new PlaylistControl (this);
 
-    m_length_totalLength = new SymbolDisplay (this,14);
+    m_length_totalLength = new SymbolDisplay (this,17);
     m_length_totalLength->setAlignment (Qt::AlignLeft);
 
     m_current_time = new SymbolDisplay (this,6);
-    m_keyboardManager = new KeyboardManager (this);
+    m_keyboardManager = new KeyboardManager (m_listWidget);
 
     connect (m_listWidget, SIGNAL (selectionChanged()), parent, SLOT (replay()));
 
@@ -102,7 +124,7 @@ PlayList::PlayList (PlayListManager *manager, QWidget *parent)
     connect (m_pl_control, SIGNAL (ejectClicked()), SIGNAL (eject()));
 
     connect (m_pl_manager, SIGNAL (selectedPlayListChanged(PlayListModel *, PlayListModel *)),
-             m_listWidget, SLOT(setModel(PlayListModel*)));
+             m_listWidget, SLOT(setModel(PlayListModel*, PlayListModel*)));
     m_listWidget->setModel(m_pl_manager->selectedPlayList());
 
     createMenus();
@@ -118,14 +140,6 @@ PlayList::PlayList (PlayListManager *manager, QWidget *parent)
 
     setCursor(m_skin->getCursor(Skin::CUR_PNORMAL));
     updatePositions();
-#ifdef Q_WS_X11
-    QString wm_name = WindowSystem::netWindowManagerName();
-    if(wm_name.contains("metacity", Qt::CaseInsensitive) ||
-       wm_name.contains("openbox", Qt::CaseInsensitive))
-        setWindowFlags (Qt::Tool | Qt::FramelessWindowHint);
-    else
-#endif
-        setWindowFlags (Qt::Dialog | Qt::FramelessWindowHint);
 }
 
 PlayList::~PlayList()
@@ -143,15 +157,20 @@ void PlayList::updatePositions()
     m_titleBar->resize (275*m_ratio+25*sx, 20*m_ratio);
     m_plslider->resize (20*m_ratio, 58*m_ratio+sy*29);
 
+    int pl_x = 12*m_ratio;
+    int pl_y = 20*m_ratio;
+    int pl_w = 243*m_ratio+25*sx;
+    int pl_h = 58*m_ratio+29*sy;
+
     if(m_pl_selector)
     {
-        m_listWidget->resize (243*m_ratio+25*sx, 58*m_ratio+29*sy - m_pl_selector->height());
         m_pl_selector->resize(243*m_ratio+25*sx, m_pl_selector->height());
         m_pl_selector->move(12*m_ratio, 20*m_ratio + 58*m_ratio+29*sy - m_pl_selector->height());
+        pl_h -= m_pl_selector->height();
     }
-    else
-        m_listWidget->resize (243*m_ratio+25*sx, 58*m_ratio+29*sy);
-    m_listWidget->move (12*m_ratio,20*m_ratio);
+
+    m_listWidget->resize (pl_w, pl_h);
+    m_listWidget->move (pl_x, pl_y);
 
     m_buttonAdd->move (11*m_ratio, 86*m_ratio+29*sy);
     m_buttonSub->move (40*m_ratio, 86*m_ratio+29*sy);
@@ -159,10 +178,10 @@ void PlayList::updatePositions()
     m_sortButton->move (99*m_ratio, 86*m_ratio+29*sy);
 
     m_pl_control->move (128*m_ratio+sx*25, 100*m_ratio+29*sy);
-    m_playlistButton->move (228*m_ratio+sx*25,86*m_ratio+29*sy);
+    m_playlistButton->move (228*m_ratio+sx*25, 86*m_ratio+29*sy);
 
-    m_length_totalLength -> move (131*m_ratio+sx*25,88*m_ratio+29*sy);
-    m_current_time->move (190*m_ratio+sx*25,101*m_ratio+29*sy);
+    m_length_totalLength -> move (132*m_ratio+sx*25, 88*m_ratio+29*sy);
+    m_current_time->move (191*m_ratio+sx*25,101*m_ratio+29*sy);
 
     m_plslider->move (255*m_ratio+sx*25,20*m_ratio);
     m_resizeWidget->move(width() - 25, height() - 29);
@@ -195,8 +214,10 @@ void PlayList::createActions()
     m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_UNSELECTED, m_pl_manager,
                                 SLOT(removeUnselected())));
     m_subMenu->addSeparator();
+    m_subMenu->addAction(SET_ACTION(ActionManager::PL_REFRESH, m_pl_manager,
+                                SLOT(refresh())));
     m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_INVALID, m_pl_manager,
-                                SLOT(removeInvalidItems())));
+                                SLOT(removeInvalidTracks())));
     m_subMenu->addAction(SET_ACTION(ActionManager::PL_REMOVE_DUPLICATES, m_pl_manager,
                                 SLOT(removeDuplicates())));
     //sort menu
@@ -222,6 +243,10 @@ void PlayList::createActions()
     connect (artistAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (artistAct, PlayListModel::ARTIST);
 
+    QAction* albumArtistAct = sort_mode_menu->addAction (tr ("By Album Artist"));
+    connect (albumArtistAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (albumArtistAct, PlayListModel::ALBUMARTIST);
+
     QAction* nameAct = sort_mode_menu->addAction (tr ("By Filename"));
     connect (nameAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (nameAct, PlayListModel::FILENAME);
@@ -242,6 +267,14 @@ void PlayList::createActions()
     connect (fileCreationDateAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (fileCreationDateAct, PlayListModel::FILE_CREATION_DATE);
 
+    QAction* fileModificationDateAct = sort_mode_menu->addAction (tr("By File Modification Date"));
+    connect (fileModificationDateAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (fileModificationDateAct, PlayListModel::FILE_MODIFICATION_DATE);
+
+    QAction* groupAct = sort_mode_menu->addAction (tr("By Group"));
+    connect (groupAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (groupAct, PlayListModel::GROUP);
+
     connect (signalMapper, SIGNAL (mapped (int)), m_pl_manager, SLOT (sort (int)));
 
     m_sortMenu->addMenu (sort_mode_menu);
@@ -265,6 +298,10 @@ void PlayList::createActions()
     connect (artistAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (artistAct, PlayListModel::ARTIST);
 
+    albumArtistAct = sort_mode_menu->addAction (tr ("By Album Artist"));
+    connect (albumArtistAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (albumArtistAct, PlayListModel::ALBUMARTIST);
+
     nameAct = sort_mode_menu->addAction (tr ("By Filename"));
     connect (nameAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (nameAct, PlayListModel::FILENAME);
@@ -285,6 +322,10 @@ void PlayList::createActions()
     connect (fileCreationDateAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
     signalMapper->setMapping (fileCreationDateAct, PlayListModel::FILE_CREATION_DATE);
 
+    fileModificationDateAct = sort_mode_menu->addAction (tr("By File Modification Date"));
+    connect (fileModificationDateAct, SIGNAL (triggered (bool)), signalMapper, SLOT (map()));
+    signalMapper->setMapping (fileModificationDateAct, PlayListModel::FILE_MODIFICATION_DATE);
+
     connect (signalMapper, SIGNAL (mapped (int)), m_pl_manager, SLOT (sortSelection (int)));
 
     m_sortMenu->addMenu (sort_mode_menu);
@@ -293,6 +334,10 @@ void PlayList::createActions()
                            m_pl_manager, SLOT(randomizeList()));
     m_sortMenu->addAction (QIcon::fromTheme("view-sort-descending"), tr("Reverse List"),
                            m_pl_manager, SLOT(reverseList()));
+
+    m_sortMenu->addAction(SET_ACTION(ActionManager::PL_GROUP_TRACKS, m_ui_settings, SLOT(setGroupsEnabled(bool))));
+    m_sortMenu->addAction(ACTION(ActionManager::PL_SHOW_HEADER));
+    ACTION(ActionManager::PL_GROUP_TRACKS)->setChecked(m_ui_settings->isGroupsEnabled());
     //playlist context menu
     m_listWidget->menu()->addAction(ActionManager::instance()->action(ActionManager::PL_SHOW_INFO));
     m_listWidget->menu()->addSeparator();
@@ -311,6 +356,7 @@ void PlayList::createActions()
     //Playlist Menu
     m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_NEW, m_pl_manager, SLOT(createPlayList())));
     m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_CLOSE, this, SLOT(deletePlaylist())));
+    m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_RENAME, this, SLOT(renamePlaylist())));
     m_playlistMenu->addSeparator();
     m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_LOAD, this, SIGNAL(loadPlaylist())));
     m_playlistMenu->addAction(SET_ACTION(ActionManager::PL_SAVE, this, SIGNAL(savePlaylist())));
@@ -325,8 +371,7 @@ void PlayList::createActions()
 void PlayList::closeEvent (QCloseEvent *e)
 {
     if (e->spontaneous ())
-        emit closed();
-    writeSettings();
+        parentWidget()->close();
 }
 
 void PlayList::paintEvent (QPaintEvent *)
@@ -362,7 +407,7 @@ void PlayList::resizeEvent (QResizeEvent *)
 
 void PlayList::mousePressEvent (QMouseEvent *e)
 {
-    m_pos = e->pos ();
+    Q_UNUSED(e);
     if (m_resizeWidget->underMouse())
     {
         m_resize = true;
@@ -376,26 +421,37 @@ void PlayList::mouseMoveEvent (QMouseEvent *e)
 {
     if (m_resize)
     {
-#ifdef Q_OS_WIN32
-        int sx = (width()-275) /25;
-        int sy = (height()-116) /29;
-    if(width() < e->x() - 14)
-           sx++;
-    else if(width() > e->x() + 14)
-           sx--;
-        if(height() < e->y() - 14)
-           sy++;
-        else if(height() > e->y() + 14)
-           sy--;
-        resize (275+25*sx,116+29*sy);
+#ifdef Q_WS_X11
+        if(m_compiz)
+#endif
+        {
+            int dx = m_ratio * 25;
+            int dy = m_ratio * 29;
+
+            int sx = ((e->x() - 275 * m_ratio) + 14) / dx;
+            int sy = ((e->y() - 116 * m_ratio) + 14) / dy;
+
+            sx = qMax(sx, 0);
+            sy = qMax(sy, 0);
+
+#ifdef Q_OS_WIN
+            resize(275 * m_ratio + dx * sx, 116 * m_ratio + dy * sy);
 #else
+            setFixedSize(275 * m_ratio + dx * sx, 116 * m_ratio + dy * sy);
+#endif
+        }
+#ifdef Q_WS_X11
+        else
+            resize (e->x() +25, e->y() +25);
+#endif
+
+
 #ifdef Q_WS_X11
         //avoid right corner moving during resize
         if(layoutDirection() == Qt::RightToLeft)
             WindowSystem::revertGravity(winId());
 #endif
-        resize (e->x() +25, e->y() +25);
-#endif
+
     }
 }
 
@@ -435,6 +491,7 @@ void PlayList::readSettings()
         }
         m_pl_selector = 0;
     }
+
     if (m_update)
     {
         m_listWidget->readSettings();
@@ -469,6 +526,13 @@ void PlayList::writeSettings()
     settings.setValue ("Skinned/pl_pos", this->pos());
 }
 
+#ifdef Q_WS_X11
+bool PlayList::useCompiz() const
+{
+    return m_compiz;
+}
+#endif
+
 void PlayList::showAddMenu()
 {
     m_addMenu->exec (m_buttonAdd->mapToGlobal (QPoint (0,0)));
@@ -513,17 +577,6 @@ void PlayList::setTime(qint64 time)
     }
 }
 
-void PlayList::updateList()
-{
-    m_listWidget->updateList();
-    m_titleBar->showCurrent();
-}
-
-PlayListItem *PlayList::currentItem()
-{
-    return m_pl_manager->currentPlayList()->currentItem();
-}
-
 void PlayList::showPlaylistMenu()
 {
     m_playlistMenu->exec (m_playlistButton->mapToGlobal (QPoint (0,0)));
@@ -538,15 +591,7 @@ void PlayList::updateSkin()
 {
     setCursor(m_skin->getCursor(Skin::CUR_PNORMAL)); // TODO shaded
     m_resizeWidget->setCursor(m_skin->getCursor (Skin::CUR_PSIZE));
-    if(m_ratio != m_skin->ratio())
-    {
-        if(m_skin->ratio() < m_ratio)
-        {
-            setMinimumSize (275*m_skin->ratio(), (m_shaded ? 14 : 116)*m_skin->ratio());
-            resize(width()*m_skin->ratio() / m_ratio, height()*m_skin->ratio() / m_ratio);
-        }
-        m_ratio = m_skin->ratio();
-    }
+    m_ratio = m_skin->ratio();
     setMinimalMode(m_shaded);
 }
 
@@ -555,6 +600,17 @@ void PlayList::deletePlaylist()
     m_pl_manager->removePlayList(m_pl_manager->selectedPlayList());
 }
 
+void PlayList::renamePlaylist()
+{
+    bool ok = false;
+    QString name = QInputDialog::getText (this,
+                                          tr("Rename Playlist"), tr("Playlist name:"),
+                                          QLineEdit::Normal,
+                                          m_pl_manager->selectedPlayList()->name(), &ok);
+    if(ok)
+        m_pl_manager->selectedPlayList()->setName(name);
+}
+
 void PlayList::showPlayLists()
 {
     if(!m_pl_browser)
@@ -575,7 +631,7 @@ void PlayList::generateCopySelectedMenu()
 
     foreach(QString name, m_pl_manager->playListNames())
     {
-        action = m_copySelectedMenu->addAction("&"+name.replace("&", "&&"));
+        m_copySelectedMenu->addAction("&"+name.replace("&", "&&"));
     }
 }
 
@@ -595,7 +651,7 @@ void PlayList::copySelectedMenuActionTriggered(QAction *action)
             //if("&" + model->name().replace("&", "&&") == actionText)
             if(model->name() == actionText)
             {
-                targetPlayList=model;
+                targetPlayList = model;
                 break;
             }
         }
@@ -605,10 +661,10 @@ void PlayList::copySelectedMenuActionTriggered(QAction *action)
         qWarning("Error: Cannot find target playlist '%s'",qPrintable(actionText));
         return;
     }
-    QList <PlayListItem *> theCopy;
-    foreach(PlayListItem *item, m_pl_manager->selectedPlayList()->selectedItems())
+    QList <PlayListTrack *> theCopy;
+    foreach(PlayListTrack *track, m_pl_manager->selectedPlayList()->selectedTracks())
     {
-        PlayListItem *newItem = new PlayListItem(*item);
+        PlayListTrack *newItem = new PlayListTrack(*track);
         theCopy << newItem;
     }
     targetPlayList->add(theCopy);
@@ -619,18 +675,36 @@ void PlayList::setMinimalMode(bool b)
     if(!m_shaded)
         m_height = height();
     m_shaded = b;
-    if(m_shaded)
+
+#ifdef Q_WS_X11
+    if(m_compiz)
     {
-        m_height = height();
-        setSizeIncrement (25*m_ratio, 1);
-        setMinimumSize (275*m_ratio, 14*m_ratio);
-        resize(width(), 14*m_ratio);
+        if(m_shaded)
+        {
+            m_height = height();
+            setFixedSize(qMax(width(), 275 * m_ratio), 14*m_ratio);
+        }
+        else
+        {
+            setFixedSize(qMax(width(), 275 * m_ratio), qMax(m_height, 116*m_ratio));
+        }
     }
     else
+#endif
     {
-        setMinimumSize(275*m_ratio, 116*m_ratio);
-        resize (width(), m_height);
-        setSizeIncrement (25*m_ratio, 29*m_ratio);
+        if(m_shaded)
+        {
+            m_height = height();
+            setSizeIncrement (25*m_ratio, 1);
+            setMinimumSize (275*m_ratio, 14*m_ratio);
+            resize(width(), 14*m_ratio);
+        }
+        else
+        {
+            setMinimumSize(275*m_ratio, 116*m_ratio);
+            resize (width(), m_height);
+            setSizeIncrement (25*m_ratio, 29*m_ratio);
+        }
     }
     updatePositions();
     update();
