@@ -4,7 +4,7 @@
 <context>
     <name>ProjectMPlugin</name>
     <message>
-        <location filename="../projectmplugin.cpp" line="39"/>
+        <location filename="../projectmplugin.cpp" line="41"/>
         <source>ProjectM</source>
         <translation>ProjectM</translation>
     </message>
@@ -12,116 +12,126 @@
 <context>
     <name>ProjectMWidget</name>
     <message>
-        <location filename="../projectmwidget.cpp" line="134"/>
+        <location filename="../projectmwidget.cpp" line="164"/>
         <source>&amp;Help</source>
         <translation>&amp;Pagalba</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="134"/>
+        <location filename="../projectmwidget.cpp" line="164"/>
         <source>F1</source>
-        <translation type="unfinished"></translation>
+        <translation>F1</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="135"/>
+        <location filename="../projectmwidget.cpp" line="165"/>
         <source>&amp;Show Song Title</source>
         <translation>&amp;Rodyti dainos pavadinimą</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="135"/>
+        <location filename="../projectmwidget.cpp" line="165"/>
         <source>F2</source>
-        <translation type="unfinished"></translation>
+        <translation>F2</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="136"/>
+        <location filename="../projectmwidget.cpp" line="166"/>
         <source>&amp;Show Preset Name</source>
         <translation>&amp;Rodyti vizualizacijos pavadinimą</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="136"/>
+        <location filename="../projectmwidget.cpp" line="166"/>
         <source>F3</source>
-        <translation type="unfinished"></translation>
+        <translation>F3</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="138"/>
+        <location filename="../projectmwidget.cpp" line="167"/>
+        <source>&amp;Show Menu</source>
+        <translation>&amp;Rodyti Meniu</translation>
+    </message>
+    <message>
+        <location filename="../projectmwidget.cpp" line="167"/>
+        <source>M</source>
+        <translation>M</translation>
+    </message>
+    <message>
+        <location filename="../projectmwidget.cpp" line="169"/>
         <source>&amp;Next Preset</source>
         <translation>&amp;Sekanti</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="138"/>
+        <location filename="../projectmwidget.cpp" line="169"/>
         <source>N</source>
-        <translation type="unfinished"></translation>
+        <translation>N</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="139"/>
+        <location filename="../projectmwidget.cpp" line="170"/>
         <source>&amp;Previous Preset</source>
         <translation>&amp;Atgal</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="139"/>
+        <location filename="../projectmwidget.cpp" line="170"/>
         <source>P</source>
-        <translation type="unfinished"></translation>
+        <translation>P</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="140"/>
+        <location filename="../projectmwidget.cpp" line="171"/>
         <source>&amp;Random Preset</source>
         <translation>&amp;Atsitiktinė</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="140"/>
+        <location filename="../projectmwidget.cpp" line="171"/>
         <source>R</source>
-        <translation type="unfinished"></translation>
+        <translation>R</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="141"/>
+        <location filename="../projectmwidget.cpp" line="172"/>
         <source>&amp;Lock Preset</source>
         <translation>&amp;Užrakinti</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="141"/>
+        <location filename="../projectmwidget.cpp" line="172"/>
         <source>L</source>
-        <translation type="unfinished"></translation>
+        <translation>L</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="174"/>
         <source>&amp;Fullscreen</source>
         <translation>&amp;Visas ekranas</translation>
     </message>
     <message>
-        <location filename="../projectmwidget.cpp" line="143"/>
+        <location filename="../projectmwidget.cpp" line="174"/>
         <source>F</source>
-        <translation type="unfinished"></translation>
+        <translation>F</translation>
     </message>
 </context>
 <context>
     <name>VisualProjectMFactory</name>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="29"/>
+        <location filename="../visualprojectmfactory.cpp" line="31"/>
         <source>ProjectM</source>
         <translation>ProjectM</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="49"/>
+        <location filename="../visualprojectmfactory.cpp" line="51"/>
         <source>About ProjectM Visual Plugin</source>
         <translation>Apie Qmmp vizualizacijos įskiepį</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="50"/>
+        <location filename="../visualprojectmfactory.cpp" line="52"/>
         <source>Qmmp ProjectM Visual Plugin</source>
         <translation>Qmmp ProjectM vizualizacijos įskiepis</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="51"/>
+        <location filename="../visualprojectmfactory.cpp" line="53"/>
         <source>This plugin adds projectM visualization</source>
         <translation>Šis įskiepis leidžia naudoti projectM vizualizacijas</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="52"/>
+        <location filename="../visualprojectmfactory.cpp" line="54"/>
         <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
         <translation>Sukūrė: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
     </message>
     <message>
-        <location filename="../visualprojectmfactory.cpp" line="53"/>
-        <source>Based on llibrojectM-qt library</source>
+        <location filename="../visualprojectmfactory.cpp" line="55"/>
+        <source>Based on libprojectM-qt library</source>
         <translation>Sukurta libprojectM-qt pagrindu</translation>
     </message>
 </context>
