@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2009-2013 by Ilya Kotov                                 *
+ *   Copyright (C) 2009-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -30,24 +30,32 @@
 #include "effectfactory.h"
 #include "inputsource.h"
 #include "statehandler.h"
-#include "audioconverter_p.h"
+#include "audioconverter.h"
 #include "qmmpaudioengine_p.h"
+#include "channelconverter_p.h"
+#include "dithering_p.h"
 #include "metadatamanager.h"
 
+#define TRANSPORT_TIMEOUT 5000 //ms
 
 QmmpAudioEngine::QmmpAudioEngine(QObject *parent)
         : AbstractEngine(parent), m_factory(0), m_output(0)
 {
-    qRegisterMetaType<Qmmp::State>("Qmmp::State");
     m_output_buf = 0;
     m_output_size = 0;
     m_bks = 0;
+    m_sample_size = 0;
     m_decoder = 0;
     m_output = 0;
-    m_replayGain = new ReplayGain;
+    m_muted = false;
+    m_replayGain = 0;
+    m_dithering = 0;
+    m_converter = new AudioConverter;
+
     m_settings = QmmpSettings::instance();
     connect(m_settings,SIGNAL(replayGainSettingsChanged()), SLOT(updateReplayGainSettings()));
-    updateReplayGainSettings();
+    connect(m_settings,SIGNAL(audioSettingsChanged()), SLOT(updateAudioSettings()));
+    connect(m_settings, SIGNAL(eqSettingsChanged()), SLOT(updateEqSettings()));
     reset();
     m_instance = this;
 }
@@ -61,23 +69,36 @@ QmmpAudioEngine::~QmmpAudioEngine()
     m_output_buf = 0;
     qDeleteAll(m_effects);
     m_instance = 0;
-    delete m_replayGain;
+    delete m_converter;
 }
 
 void QmmpAudioEngine::reset()
 {
     m_done = false;
     m_finish = false;
-    m_totalTime = 0;
     m_seekTime = -1;
     m_output_at = 0;
     m_user_stop = false;
     m_bitrate = 0;
-    m_chan = 0;
-    m_bps = 0;
     m_next = false;
 }
 
+void QmmpAudioEngine::clearDecoders()
+{
+    if(m_decoder)
+    {
+        m_inputs.take(m_decoder)->deleteLater ();
+        delete m_decoder;
+        m_decoder = 0;
+    }
+    while(!m_decoders.isEmpty())
+    {
+        Decoder *d = m_decoders.dequeue();
+        m_inputs.take(d)->deleteLater ();
+        delete d;
+    }
+}
+
 bool QmmpAudioEngine::play()
 {
     if(isRunning() || m_decoders.isEmpty() || (m_output && m_output->isRunning()))
@@ -87,7 +108,11 @@ bool QmmpAudioEngine::play()
     prepareEffects(m_decoders.head());
     if(!(m_output = createOutput()))
         return false;
+#ifdef Q_OS_WIN
+    start(QThread::HighPriority);
+#else
     start();
+#endif
     return true;
 }
 
@@ -129,22 +154,16 @@ bool QmmpAudioEngine::enqueue(InputSource *source)
         delete decoder;
         return false;
     }
+    mutex()->lock();
     m_decoders.enqueue(decoder);
     m_inputs.insert(decoder, source);
+    mutex()->unlock();
     if(!decoder->totalTime())
         source->setOffset(-1);
     source->setParent(this);
     return true;
 }
 
-qint64 QmmpAudioEngine::totalTime()
-{
-    if(m_decoder)
-        return m_decoder->totalTime();
-    else
-        return 0;
-}
-
 void QmmpAudioEngine::addEffect(EffectFactory *factory)
 {
     foreach(Effect *effect, m_effects)
@@ -161,7 +180,7 @@ void QmmpAudioEngine::addEffect(EffectFactory *factory)
         Effect *effect = Effect::create(factory);
         if(!effect)
             return;
-        effect->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
+        effect->configure(m_ap.sampleRate(), m_ap.channelMap());
         if(effect->audioParameters() == m_ap)
         {
             mutex()->lock();
@@ -230,6 +249,17 @@ void QmmpAudioEngine::pause()
 
 }
 
+void QmmpAudioEngine::setMuted(bool muted)
+{
+    m_muted = muted;
+    if(m_output)
+    {
+        m_output->mutex()->lock();
+        m_output->setMuted(muted);
+        m_output->mutex()->unlock();
+    }
+}
+
 void QmmpAudioEngine::stop()
 {
     mutex()->lock ();
@@ -261,32 +291,28 @@ void QmmpAudioEngine::stop()
         m_output = 0;
     }
 
-    while(!m_decoders.isEmpty())
-    {
-        Decoder *d = m_decoders.dequeue();
-        m_inputs.take(d)->deleteLater ();
-        delete d;
-    }
+    clearDecoders();
     reset();
-    m_decoder = 0;
     while(!m_effects.isEmpty()) //delete effects
         delete m_effects.takeFirst();
+    m_replayGain = 0;
 }
 
-qint64 QmmpAudioEngine::produceSound(char *data, qint64 size, quint32 brate)
+qint64 QmmpAudioEngine::produceSound(unsigned char *data, qint64 size, quint32 brate)
 {
     Buffer *b = m_output->recycler()->get();
-    uint sz = size < m_bks ? size : m_bks;
-    m_replayGain->applyReplayGain(data, sz);
-    memcpy(b->data, data, sz);
-    b->nbytes = sz;
+    size_t sz = size < m_bks ? size : m_bks;
+    size_t samples = sz / m_sample_size;
+
+    m_converter->toFloat(data, b->data, samples);
+
+    b->samples = samples;
     b->rate = brate;
     foreach(Effect* effect, m_effects)
     {
         effect->applyEffect(b);
     }
-    size -= sz;
-    memmove(data, data + sz, size);
+    memmove(data, data + sz, size - sz);
     m_output->recycler()->add();
     return sz;
 }
@@ -303,12 +329,33 @@ void QmmpAudioEngine::finish()
 }
 
 void QmmpAudioEngine::updateReplayGainSettings()
+{
+    if(m_replayGain)
+    {
+        mutex()->lock();
+        m_replayGain->updateSettings(m_settings->replayGainMode(),
+                                     m_settings->replayGainPreamp(),
+                                     m_settings->replayGainDefaultGain(),
+                                     m_settings->replayGainPreventClipping());
+        mutex()->unlock();
+    }
+}
+
+void QmmpAudioEngine::updateAudioSettings()
+{
+    if(m_dithering)
+    {
+        mutex()->lock();
+        m_dithering->setEnabled(m_settings->useDithering());
+        mutex()->unlock();
+    }
+}
+
+void QmmpAudioEngine::updateEqSettings()
 {
     mutex()->lock();
-    m_replayGain->updateSettings(m_settings->replayGainMode(),
-                                 m_settings->replayGainPreamp(),
-                                 m_settings->replayGainDefaultGain(),
-                                 m_settings->replayGainPreventClipping());
+    if(m_output)
+        m_output->updateEqSettings();
     mutex()->unlock();
 }
 
@@ -317,6 +364,7 @@ void QmmpAudioEngine::run()
     mutex()->lock ();
     m_next = false;
     qint64 len = 0;
+    int delay = 0;
     if(m_decoders.isEmpty())
     {
          mutex()->unlock ();
@@ -324,13 +372,15 @@ void QmmpAudioEngine::run()
     }
     m_decoder = m_decoders.dequeue();
     addOffset(); //offset
-    m_replayGain->setReplayGainInfo(m_decoder->replayGainInfo());
     mutex()->unlock();
     m_output->start();
+    m_dithering->setFormats(m_decoder->audioParameters().format(), m_output->format());
+    StateHandler::instance()->dispatch(Qmmp::Buffering);
+    StateHandler::instance()->dispatch(m_decoder->totalTime());
     StateHandler::instance()->dispatch(Qmmp::Playing);
     sendMetaData();
 
-    while (! m_done && ! m_finish)
+    while (!m_done && !m_finish)
     {
         mutex()->lock ();
         //seek
@@ -345,21 +395,50 @@ void QmmpAudioEngine::run()
         }
         //metadata
         if(m_decoder->hasMetaData())
-            StateHandler::instance()->dispatch(m_decoder->takeMetaData());
+        {
+            QMap<Qmmp::MetaData, QString> m = m_decoder->takeMetaData();
+            m[Qmmp::URL] = m_inputs[m_decoder]->url();
+            StateHandler::instance()->dispatch(m);
+        }
         if(m_inputs[m_decoder]->hasMetaData())
-            StateHandler::instance()->dispatch(m_inputs[m_decoder]->takeMetaData());
+        {
+            QMap<Qmmp::MetaData, QString> m = m_inputs[m_decoder]->takeMetaData();
+            m[Qmmp::URL] = m_inputs[m_decoder]->url();
+            StateHandler::instance()->dispatch(m);
+        }
         if(m_inputs[m_decoder]->hasStreamInfo())
             StateHandler::instance()->dispatch(m_inputs[m_decoder]->takeStreamInfo());
-
-        // decode
-        len = m_decoder->read((char *)(m_output_buf + m_output_at), m_output_size - m_output_at);
+        //wait more data
+        if(m_inputs[m_decoder]->isWaiting())
+        {
+            mutex()->unlock();
+            msleep(5);
+            delay += 5;
+            mutex()->lock();
+            m_done = m_user_stop;
+            mutex()->unlock();
+            if(delay > TRANSPORT_TIMEOUT)
+            {
+                qWarning("QmmpAudioEngine: unable to receive more data");
+                m_done = true;
+                StateHandler::instance()->dispatch(Qmmp::NormalError);
+                break;
+            }
+            else
+                continue;
+        }
+        else
+        {
+            delay = 0;
+            // decode
+            len = m_decoder->read((m_output_buf + m_output_at), m_output_size - m_output_at);
+        }
 
         if (len > 0)
         {
             m_bitrate = m_decoder->bitrate();
             m_output_at += len;
-            if (m_output)
-                flush();
+            flush();
         }
         else if (len == 0)
         {
@@ -370,22 +449,24 @@ void QmmpAudioEngine::run()
                 StateHandler::instance()->sendFinished();
                 StateHandler::instance()->dispatch(Qmmp::Stopped); //fake stop/start cycle
                 StateHandler::instance()->dispatch(Qmmp::Buffering);
-                StateHandler::instance()->dispatch(Qmmp::Playing);
                 m_decoder->next();
+                StateHandler::instance()->dispatch(m_decoder->totalTime());
                 m_replayGain->setReplayGainInfo(m_decoder->replayGainInfo());
+                m_output->mutex()->lock();
                 m_output->seek(0); //reset counter
+                m_output->mutex()->unlock();
                 addOffset(); //offset
+                StateHandler::instance()->dispatch(Qmmp::Playing);
                 mutex()->unlock();
                 continue;
             }
             else if(!m_decoders.isEmpty())
             {
                 m_inputs.take(m_decoder)->deleteLater ();
-                Decoder *d = m_decoder;
+                delete m_decoder;
                 m_decoder = m_decoders.dequeue();
-                delete d;
                 //m_seekTime = m_inputs.value(m_decoder)->offset();
-                m_replayGain->setReplayGainInfo(m_decoder->replayGainInfo());
+                flush(true);
                 //use current output if possible
                 prepareEffects(m_decoder);
                 if(m_ap == m_output->audioParameters())
@@ -393,16 +474,17 @@ void QmmpAudioEngine::run()
                     StateHandler::instance()->sendFinished();
                     StateHandler::instance()->dispatch(Qmmp::Stopped); //fake stop/start cycle
                     StateHandler::instance()->dispatch(Qmmp::Buffering);
-                    StateHandler::instance()->dispatch(Qmmp::Playing);
+                    StateHandler::instance()->dispatch(m_decoder->totalTime());
+                    m_output->mutex()->lock();
                     m_output->seek(0); //reset counter
+                    m_output->mutex()->unlock();
+                    StateHandler::instance()->dispatch(Qmmp::Playing);
                     mutex()->unlock();
                     sendMetaData();
                     addOffset(); //offset
-                    continue;
                 }
                 else
                 {
-                    flush(true);
                     finish();
                     //wake up waiting threads
                     mutex()->unlock();
@@ -417,11 +499,16 @@ void QmmpAudioEngine::run()
                     {
                         m_output->start();
                         StateHandler::instance()->dispatch(Qmmp::Playing);
+                        StateHandler::instance()->dispatch(m_decoder->totalTime());
                         sendMetaData();
                         addOffset(); //offset
-                        continue;
                     }
                 }
+                if(m_output)
+                {
+                    m_dithering->setFormats(m_decoder->audioParameters().format(), m_output->format());
+                    continue;
+                }
             }
 
             flush(true);
@@ -438,21 +525,19 @@ void QmmpAudioEngine::run()
                 }
                 m_output->recycler()->mutex()->unlock();
             }
-            m_done = true;
-            m_finish = !m_user_stop;
+
+            //continue if new input was queued
+            if(m_decoders.isEmpty() || m_user_stop)
+            {
+                m_done = true;
+                m_finish = !m_user_stop;
+            }
         }
         else
             m_finish = true;
         mutex()->unlock();
     }
-    if(m_decoder)
-    {
-        m_inputs.take(m_decoder)->deleteLater ();
-        Decoder *d = m_decoder;
-        m_decoder = 0;
-        delete d;
-    }
-
+    clearDecoders();
     mutex()->lock ();
     m_next = false;
     if (m_finish)
@@ -492,7 +577,7 @@ void QmmpAudioEngine::flush(bool final)
             m_done = true;
         else
         {
-            m_output_at -= produceSound((char*)m_output_buf, m_output_at, m_bitrate);
+            m_output_at -= produceSound(m_output_buf, m_output_at, m_bitrate);
         }
 
         if (!m_output->recycler()->empty())
@@ -534,68 +619,70 @@ void QmmpAudioEngine::sendMetaData()
 OutputWriter *QmmpAudioEngine::createOutput()
 {
     OutputWriter *output = new OutputWriter(0);
-    if (!output->initialize(m_ap.sampleRate(), m_ap.channels(), m_ap.format()))
+    output->setMuted(m_muted);
+    if (!output->initialize(m_ap.sampleRate(), m_ap.channelMap()))
     {
         delete output;
         StateHandler::instance()->dispatch(Qmmp::FatalError);
         return 0;
     }
-    if(output->audioParameters() != m_ap)
-    {
-        if(output->audioParameters().format() == Qmmp::PCM_S16LE) //output supports 16 bit only
-        {
-            Effect *effect = new AudioConverter();
-            effect->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
-            m_ap = effect->audioParameters();
-            m_effects.append(effect);
-            qDebug("QmmpAudioEngine: output plugin requires 16 bit, using 16-bit converter");
-        }
-        else
-        {
-            qWarning("QmmpAudioEngine: unsupported audio format");
-            delete output;
-            StateHandler::instance()->dispatch(Qmmp::FatalError);
-            return 0;
-        }
-    }
-
-    if(m_output_buf)
-        delete [] m_output_buf;
-    m_bks = QMMP_BLOCK_FRAMES * m_ap.channels() * m_ap.sampleSize();
-    m_output_size = m_bks * 4;
-    m_output_buf = new unsigned char[m_output_size];
     return output;
 }
 
 void QmmpAudioEngine::prepareEffects(Decoder *d)
 {
     m_ap = d->audioParameters();
-    m_replayGain->setFormat(m_ap.format());
-
-    foreach(Effect *e, m_effects) //remove disabled and external effects
+    //output buffer for decoder
+    if(m_output_buf)
+        delete [] m_output_buf;
+    m_bks = QMMP_BLOCK_FRAMES * m_ap.channels() * m_ap.sampleSize(); //block size
+    m_output_size = m_bks * 4;
+    m_sample_size = m_ap.sampleSize();
+    m_output_buf = new unsigned char[m_output_size];
+    //audio converter
+    m_converter->configure(m_ap.format());
+    m_ap = AudioParameters(m_ap.sampleRate(), m_ap.channelMap(), Qmmp::PCM_FLOAT);
+    //remove disabled and external effects
+    foreach(Effect *e, m_effects)
     {
         if(!e->factory() || !Effect::isEnabled(e->factory()))
         {
             m_effects.removeAll(e);
             m_blockedEffects.removeAll(e);
-            delete e;
         }
     }
+    m_replayGain = 0;
+    m_dithering = 0;
     QList <Effect *> tmp_effects = m_effects;
     m_effects.clear();
 
-    if(m_settings->use16BitOutput())
+    //replay gain
     {
-        m_effects << new AudioConverter();
-        m_effects.at(0)->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
-        m_ap = m_effects.at(0)->audioParameters();
+        m_replayGain = new ReplayGain();
+        m_replayGain->configure(m_ap.sampleRate(), m_ap.channelMap());
+        m_effects << m_replayGain;
+        m_replayGain->updateSettings(m_settings->replayGainMode(),
+                                     m_settings->replayGainPreamp(),
+                                     m_settings->replayGainDefaultGain(),
+                                     m_settings->replayGainPreventClipping());
+        m_replayGain->setReplayGainInfo(d->replayGainInfo());
+    }
+    //dithering
+    {
+        m_dithering = new Dithering;
+        m_dithering->configure(m_ap.sampleRate(), m_ap.channelMap());
+        m_effects << m_dithering;
+    }
+    //channel order converter
+    if(m_ap.channelMap() != m_ap.channelMap().remaped())
+    {
+        m_effects << new ChannelConverter(m_ap.channelMap().remaped());
+        m_effects.last()->configure(m_ap.sampleRate(), m_ap.channelMap());
+        m_ap = m_effects.last()->audioParameters();
     }
 
-    foreach(EffectFactory *factory, *Effect::factories())
+    foreach(EffectFactory *factory, Effect::enabledFactories())
     {
-        if(!Effect::isEnabled(factory))
-            continue;
-
         Effect *effect = 0;
         foreach(Effect *e, tmp_effects) //find effect
         {
@@ -614,7 +701,7 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
         if(!effect)
         {
             effect = Effect::create(factory);
-            effect->configure(m_ap.sampleRate(), m_ap.channels(), m_ap.format());
+            effect->configure(m_ap.sampleRate(), m_ap.channelMap());
             if (m_ap != effect->audioParameters())
             {
                 m_blockedEffects << effect; //list of effects which require restart
@@ -624,7 +711,6 @@ void QmmpAudioEngine::prepareEffects(Decoder *d)
         m_effects << effect;
         tmp_effects.removeAll(effect);
     }
-    m_chan = m_ap.channels();
 }
 
 //static members
