@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007-2012 by Ilya Kotov                                 *
+ *   Copyright (C) 2007-2016 by Ilya Kotov                                 *
  *   forkotov02@hotmail.ru                                                 *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -51,6 +51,7 @@
 #include "mediaplayer.h"
 #include "qmmpuisettings.h"
 #include "playlistmodel.h"
+#include "winfileassocpage_p.h"
 #include "configdialog.h"
 
 ConfigDialog::ConfigDialog (QWidget *parent) : QDialog (parent)
@@ -63,10 +64,14 @@ ConfigDialog::ConfigDialog (QWidget *parent) : QDialog (parent)
     m_ui->preferencesButton->setEnabled(false);
     m_ui->informationButton->setEnabled(false);
     m_ui->treeWidget->setItemDelegate(new RadioItemDelegate(this));
+    m_ui->treeWidget->header()->setMovable(false);
     connect (this, SIGNAL(rejected()),SLOT(saveSettings()));
     m_ui->replayGainModeComboBox->addItem (tr("Track"), QmmpSettings::REPLAYGAIN_TRACK);
     m_ui->replayGainModeComboBox->addItem (tr("Album"), QmmpSettings::REPLAYGAIN_ALBUM);
     m_ui->replayGainModeComboBox->addItem (tr("Disabled"), QmmpSettings::REPLAYGAIN_DISABLED);
+    m_ui->bitDepthComboBox->addItem("16", Qmmp::PCM_S16LE);
+    m_ui->bitDepthComboBox->addItem("24", Qmmp::PCM_S24LE);
+    m_ui->bitDepthComboBox->addItem("32", Qmmp::PCM_S32LE);
     readSettings();
     loadPluginsInfo();
     loadLanguages();
@@ -74,6 +79,15 @@ ConfigDialog::ConfigDialog (QWidget *parent) : QDialog (parent)
     //setup icons
     m_ui->preferencesButton->setIcon(QIcon::fromTheme("configure"));
     m_ui->informationButton->setIcon(QIcon::fromTheme("dialog-information"));
+    //file associations
+#ifdef Q_OS_WIN
+    if(!Qmmp::isPortable())
+    {
+        m_ui->stackedWidget->addWidget(new WinFileAssocPage(this));
+        m_ui->contentsWidget->addItem(tr("File Types"));
+        m_ui->contentsWidget->item(m_ui->contentsWidget->count() - 1)->setIcon(QIcon(":associations.png"));
+    }
+#endif
 }
 
 ConfigDialog::~ConfigDialog()
@@ -96,15 +110,16 @@ void ConfigDialog::readSettings()
     {
         //playlist options
         QmmpUiSettings *guis = QmmpUiSettings::instance();
-        m_ui->formatLineEdit->setText(guis->format());
+        m_ui->groupLineEdit->setText(guis->groupFormat());
         m_ui->metadataCheckBox->setChecked(guis->useMetadata());
         m_ui->underscoresCheckBox->setChecked(guis->convertUnderscore());
         m_ui->per20CheckBox->setChecked(guis->convertTwenty());
+        m_ui->clearPrevPLCheckBox->setChecked(guis->clearPreviousPlayList());
         //resume playback on startup
         m_ui->continuePlaybackCheckBox->setChecked(guis->resumeOnStartup());
         //directory filters
-        m_ui->dirRestrictLineEdit->setText(guis->restrictFilters().join(";").trimmed());
-        m_ui->dirExcludeLineEdit->setText(guis->excludeFilters().join(";").trimmed());
+        m_ui->dirRestrictLineEdit->setText(guis->restrictFilters().join(",").trimmed());
+        m_ui->dirExcludeLineEdit->setText(guis->excludeFilters().join(",").trimmed());
         //default playlist
         m_ui->defaultPlayListCheckBox->setChecked(guis->useDefaultPlayList());
         m_ui->defaultPlayListLineEdit->setText(guis->defaultPlayListName());
@@ -140,8 +155,10 @@ void ConfigDialog::readSettings()
     m_ui->preampDoubleSpinBox->setValue(gs->replayGainPreamp());
     m_ui->defaultGainDoubleSpinBox->setValue(gs->replayGainDefaultGain());
     //audio
+    m_ui->volumeStepSpinBox->setValue(gs->volumeStep());
     m_ui->softVolumeCheckBox->setChecked(gs->useSoftVolume());
-    m_ui->use16BitCheckBox->setChecked(gs->use16BitOutput());
+    m_ui->bitDepthComboBox->setCurrentIndex(m_ui->bitDepthComboBox->findData(gs->outputFormat()));
+    m_ui->ditheringCheckBox->setChecked(gs->useDithering());
     m_ui->bufferSizeSpinBox->setValue(gs->bufferSize());
     //geometry
     QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
@@ -172,7 +189,7 @@ void ConfigDialog::loadPluginsInfo()
         load transport plugin information
      */
     QTreeWidgetItem *item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("Transports"));
-    foreach(InputSourceFactory *factory, *InputSource::factories())
+    foreach(InputSourceFactory *factory, InputSource::factories())
     {
         new PluginItem (item, factory,  InputSource::file(factory));
     }
@@ -182,7 +199,7 @@ void ConfigDialog::loadPluginsInfo()
         load input plugins information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("Decoders"));
-    foreach(DecoderFactory *factory, *Decoder::factories())
+    foreach(DecoderFactory *factory, Decoder::factories())
     {
         new PluginItem (item, factory,  Decoder::file(factory));
     }
@@ -192,7 +209,7 @@ void ConfigDialog::loadPluginsInfo()
         load audio engines information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("Engines"));
-    foreach(EngineFactory *factory, *AbstractEngine::factories())
+    foreach(EngineFactory *factory, AbstractEngine::factories())
     {
         new PluginItem (item, factory,  AbstractEngine::file(factory));
     }
@@ -202,7 +219,7 @@ void ConfigDialog::loadPluginsInfo()
         load effect plugin information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("Effects"));
-    foreach(EffectFactory *factory, *Effect::factories())
+    foreach(EffectFactory *factory, Effect::factories())
     {
         new PluginItem (item, factory, Effect::file(factory));
     }
@@ -212,7 +229,7 @@ void ConfigDialog::loadPluginsInfo()
         load visual plugin information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("Visualization"));
-    foreach(VisualFactory *factory, *Visual::factories())
+    foreach(VisualFactory *factory, Visual::factories())
     {
         new PluginItem (item, factory, Visual::file(factory));
     }
@@ -222,7 +239,7 @@ void ConfigDialog::loadPluginsInfo()
         load general plugin information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("General"));
-    foreach(GeneralFactory *factory, *General::factories())
+    foreach(GeneralFactory *factory, General::factories())
     {
         new PluginItem (item, factory, General::file(factory));
     }
@@ -232,7 +249,7 @@ void ConfigDialog::loadPluginsInfo()
         load output plugins information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("Output"));
-    foreach(OutputFactory *factory, *Output::factories())
+    foreach(OutputFactory *factory, Output::factories())
     {
         new PluginItem (item, factory, Output::file(factory));
     }
@@ -242,7 +259,7 @@ void ConfigDialog::loadPluginsInfo()
         load file dialogs information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("File Dialogs"));
-    foreach(FileDialogFactory *factory, *FileDialog::factories())
+    foreach(FileDialogFactory *factory, FileDialog::factories())
     {
         new PluginItem (item, factory, FileDialog::file(factory));
     }
@@ -252,7 +269,7 @@ void ConfigDialog::loadPluginsInfo()
         load user interfaces information
     */
     item = new QTreeWidgetItem (m_ui->treeWidget, QStringList() << tr("User Interfaces"));
-    foreach(UiFactory *factory, *UiLoader::factories())
+    foreach(UiFactory *factory, UiLoader::factories())
     {
         new PluginItem (item, factory, UiLoader::file(factory));
     }
@@ -281,25 +298,33 @@ void ConfigDialog::on_informationButton_clicked()
 
 void ConfigDialog::createMenus()
 {
-    QMenu *menu = new QMenu(this);
+    QMenu *groupMenu = new QMenu(this);
 
-    menu->addAction(tr("Artist"))->setData("%p");
-    menu->addAction(tr("Album"))->setData("%a");
-    menu->addAction(tr("Title"))->setData("%t");
-    menu->addAction(tr("Track number"))->setData("%n");
-    menu->addAction(tr("Two-digit track number"))->setData("%NN");
-    menu->addAction(tr("Genre"))->setData("%g");
-    menu->addAction(tr("Comment"))->setData("%c");
-    menu->addAction(tr("Composer"))->setData("%C");
-    menu->addAction(tr("Disc number"))->setData("%D");
-    menu->addAction(tr("File name"))->setData("%f");
-    menu->addAction(tr("File path"))->setData("%F");
-    menu->addAction(tr("Year"))->setData("%y");
-    menu->addAction(tr("Condition"))->setData("%if(%p&%t,%p - %t,%f)");
+    groupMenu->addAction(tr("Artist"))->setData("%p");
+    groupMenu->addAction(tr("Album"))->setData("%a");
+    groupMenu->addAction(tr("Album Artist"))->setData("%aa");
+    groupMenu->addAction(tr("Genre"))->setData("%g");
+    groupMenu->addAction(tr("Comment"))->setData("%c");
+    groupMenu->addAction(tr("Composer"))->setData("%C");
+    groupMenu->addAction(tr("Disc Number"))->setData("%D");
+    groupMenu->addAction(tr("Year"))->setData("%y");
+    groupMenu->addAction(tr("Condition"))->setData("%if(%p&%a,%p - %a,%p%a)");
+    groupMenu->addAction(tr("Artist/Album"))->setData("%p%if(%p&%a, - ,)%a");
+    groupMenu->addAction(tr("Artist/Year/Album"))->setData("%p%if(%p&%a, - %if(%y,[%y] ,),)%a");
 
-    m_ui->titleButton->setMenu(menu);
-    m_ui->titleButton->setPopupMode(QToolButton::InstantPopup);
-    connect(menu, SIGNAL(triggered (QAction *)), SLOT(addTitleString(QAction *)));
+    m_ui->groupButton->setMenu(groupMenu);
+    m_ui->groupButton->setPopupMode(QToolButton::InstantPopup);
+    connect(groupMenu, SIGNAL(triggered (QAction *)), SLOT(addGroupString(QAction *)));
+
+    m_ui->treeWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
+    m_preferencesAction = new QAction(QIcon::fromTheme("configure"),tr("Preferences"), m_ui->treeWidget);
+    m_preferencesAction->setEnabled(false);
+    m_ui->treeWidget->addAction(m_preferencesAction);
+    m_informationAction = new QAction(QIcon::fromTheme("dialog-information"),tr("Information"), m_ui->treeWidget);
+    m_informationAction->setEnabled(false);
+    m_ui->treeWidget->addAction(m_informationAction);
+    connect(m_preferencesAction, SIGNAL(triggered()), SLOT(on_preferencesButton_clicked()));
+    connect(m_informationAction, SIGNAL(triggered()), SLOT(on_informationButton_clicked()));
 }
 
 void ConfigDialog::loadLanguages()
@@ -322,11 +347,14 @@ void ConfigDialog::loadLanguages()
     l["kk"] = tr("Kazakh");
     l["lt"] = tr("Lithuanian");
     l["pl_PL"] = tr("Polish");
+    l["pt"] = tr("Portuguese");
     l["ru_RU"] = tr("Russian");
     l["sk"] = tr("Slovak");
     l["es"] = tr("Spanish");
     l["tr"] = tr("Turkish");
     l["uk_UA"] = tr("Ukrainian");
+    l["sr_BA"] = tr("Serbian (Ijekavian)");
+    l["sr_RS"] = tr("Serbian (Ekavian)");
 
     foreach(QString code, l.keys())
     {
@@ -341,22 +369,23 @@ void ConfigDialog::loadLanguages()
     m_ui->langComboBox->setCurrentIndex(index);
 }
 
-void ConfigDialog::addTitleString(QAction * a)
+void ConfigDialog::addGroupString(QAction *a)
 {
-    if (m_ui->formatLineEdit->cursorPosition () < 1)
-        m_ui->formatLineEdit->insert(a->data().toString());
+    if (m_ui->groupLineEdit->cursorPosition () < 1)
+        m_ui->groupLineEdit->insert(a->data().toString());
     else
-        m_ui->formatLineEdit->insert(" - "+a->data().toString());
+        m_ui->groupLineEdit->insert(" - "+a->data().toString());
 }
 
 void ConfigDialog::saveSettings()
 {
     if (QmmpUiSettings *guis = QmmpUiSettings::instance())
     {
-        guis->setFormat(m_ui->formatLineEdit->text().trimmed());
+        guis->setGroupFormat(m_ui->groupLineEdit->text().trimmed());
         guis->setUseMetadata(m_ui->metadataCheckBox->isChecked());
         guis->setConvertUnderscore(m_ui->underscoresCheckBox->isChecked());
         guis->setConvertTwenty(m_ui->per20CheckBox->isChecked());
+        guis->setClearPreviousPlayList(m_ui->clearPrevPLCheckBox->isChecked());
         guis->setResumeOnStartup(m_ui->continuePlaybackCheckBox->isChecked());
         guis->setRestrictFilters(m_ui->dirRestrictLineEdit->text());
         guis->setExcludeFilters(m_ui->dirExcludeLineEdit->text());
@@ -364,7 +393,6 @@ void ConfigDialog::saveSettings()
                                  m_ui->defaultPlayListCheckBox->isChecked());
         guis->setAutoSavePlayList(m_ui->autoSavePlayListCheckBox->isChecked());
         guis->setUseClipboard(m_ui->clipboardCheckBox->isChecked());
-        guis->sync();
     }
 
     QmmpSettings *gs = QmmpSettings::instance();
@@ -388,10 +416,13 @@ void ConfigDialog::saveSettings()
                               m_ui->preampDoubleSpinBox->value(),
                               m_ui->defaultGainDoubleSpinBox->value(),
                               m_ui->clippingCheckBox->isChecked());
-    gs->setAudioSettings(m_ui->softVolumeCheckBox->isChecked(), m_ui->use16BitCheckBox->isChecked());
+    i = m_ui->bitDepthComboBox->currentIndex();
+    gs->setAudioSettings(m_ui->softVolumeCheckBox->isChecked(),
+                         (Qmmp::AudioFormat)m_ui->bitDepthComboBox->itemData(i).toInt(),
+                         m_ui->ditheringCheckBox->isChecked());
     gs->setBufferSize(m_ui->bufferSizeSpinBox->value());
     gs->setDetermineFileTypeByContent(m_ui->byContentCheckBox->isChecked());
-    gs->sync();
+    gs->setVolumeStep(m_ui->volumeStepSpinBox->value());
     QList<QVariant> var_sizes;
     var_sizes << m_ui->splitter->sizes().first() << m_ui->splitter->sizes().last();
     QSettings settings (Qmmp::configFile(), QSettings::IniFormat);
@@ -421,4 +452,6 @@ void ConfigDialog::on_treeWidget_currentItemChanged (QTreeWidgetItem *current, Q
         m_ui->preferencesButton->setEnabled(false);
         m_ui->informationButton->setEnabled(false);
     }
+    m_preferencesAction->setEnabled(m_ui->preferencesButton->isEnabled());
+    m_informationAction->setEnabled(m_ui->informationButton->isEnabled());
 }
